@@ -87,19 +87,15 @@ private:
 
   // Helper methods
   SPIRVType *getVoidTy();
-  SPIRVType *getInt32Ty();
   SPIRVEntry *getScope(DIScope *SR);
   SPIRVEntry *getGlobalVariable(const DIGlobalVariable *GV);
-  inline bool isNonSemanticDebugInfo();
-  void transformToConstant(std::vector<SPIRVWord> &Ops,
-                           std::vector<SPIRVWord> Idxs);
 
   // No debug info
   SPIRVEntry *getDebugInfoNone();
   SPIRVId getDebugInfoNoneId();
 
   // Compilation unit
-  SPIRVEntry *transDbgCompileUnit(const DICompileUnit *CU);
+  SPIRVEntry *transDbgCompilationUnit(const DICompileUnit *CU);
 
   /// The following methods (till the end of the file) implement translation
   /// of debug instrtuctions described in the spec.
@@ -109,18 +105,11 @@ private:
   SPIRVEntry *transDbgPointerType(const DIDerivedType *PT);
   SPIRVEntry *transDbgQualifiedType(const DIDerivedType *QT);
   SPIRVEntry *transDbgArrayType(const DICompositeType *AT);
-  SPIRVEntry *transDbgArrayTypeOpenCL(const DICompositeType *AT);
-  SPIRVEntry *transDbgArrayTypeNonSemantic(const DICompositeType *AT);
-  SPIRVEntry *transDbgArrayTypeDynamic(const DICompositeType *AT);
-  SPIRVEntry *transDbgSubrangeType(const DISubrange *ST);
-  SPIRVEntry *transDbgStringType(const DIStringType *ST);
   SPIRVEntry *transDbgTypeDef(const DIDerivedType *D);
   SPIRVEntry *transDbgSubroutineType(const DISubroutineType *FT);
   SPIRVEntry *transDbgEnumType(const DICompositeType *ET);
   SPIRVEntry *transDbgCompositeType(const DICompositeType *CT);
   SPIRVEntry *transDbgMemberType(const DIDerivedType *MT);
-  SPIRVEntry *transDbgMemberTypeOpenCL(const DIDerivedType *MT);
-  SPIRVEntry *transDbgMemberTypeNonSemantic(const DIDerivedType *MT);
   SPIRVEntry *transDbgInheritance(const DIDerivedType *DT);
   SPIRVEntry *transDbgPtrToMember(const DIDerivedType *DT);
 
@@ -136,23 +125,15 @@ private:
   SPIRVEntry *transDbgGlobalVariable(const DIGlobalVariable *GV);
   SPIRVEntry *transDbgFunction(const DISubprogram *Func);
 
-  SPIRVEntry *transDbgFuncDefinition(SPIRVValue *SPVFunc, SPIRVEntry *DbgFunc);
-  SPIRVEntry *transDbgEntryPoint(const DISubprogram *Func, SPIRVEntry *DbgFunc);
-
   // Location information
   SPIRVEntry *transDbgScope(const DIScope *S);
   SPIRVEntry *transDebugLoc(const DebugLoc &Loc, SPIRVBasicBlock *BB,
                             SPIRVInstruction *InsertBefore = nullptr);
   SPIRVEntry *transDbgInlinedAt(const DILocation *D);
-  SPIRVEntry *transDbgInlinedAtNonSemanticShader200(const DILocation *D);
 
   template <class T> SPIRVExtInst *getSource(const T *DIEntry);
   SPIRVEntry *transDbgFileType(const DIFile *F);
 
-  // Generate instructions recording identifier and file where debug information
-  // was split to
-  void generateBuildIdentifierAndStoragePath(const DICompileUnit *DIEntry);
-
   // Local Variables
   SPIRVEntry *transDbgLocalVariable(const DILocalVariable *Var);
 
@@ -165,25 +146,17 @@ private:
   // A module in programming language. Example - Fortran module, clang module.
   SPIRVEntry *transDbgModule(const DIModule *IE);
 
-  // Flags
-  SPIRVWord mapDebugFlags(DINode::DIFlags DFlags);
-  SPIRVWord transDebugFlags(const DINode *DN);
-
   SPIRVModule *BM;
   Module *M;
   LLVMToSPIRVBase *SPIRVWriter;
   std::unordered_map<const MDNode *, SPIRVEntry *> MDMap;
   std::unordered_map<std::string, SPIRVExtInst *> FileMap;
   DebugInfoFinder DIF;
-  SPIRVType *VoidT = nullptr;
-  SPIRVType *Int32T = nullptr;
+  SPIRVType *VoidT;
   SPIRVEntry *DebugInfoNone;
-  std::unordered_map<const DICompileUnit *, SPIRVExtInst *> SPIRVCUMap;
+  SPIRVExtInst *SPIRVCU = nullptr;
   std::vector<const DbgVariableIntrinsic *> DbgDeclareIntrinsics;
   std::vector<const DbgVariableIntrinsic *> DbgValueIntrinsics;
-
-  SPIRVExtInst *BuildIdentifierInsn{nullptr};
-  SPIRVExtInst *StoragePathInsn{nullptr};
 }; // class LLVMToSPIRVDbgTran
 
 } // namespace SPIRV
