@@ -51,7 +51,6 @@
 #include "llvm/Support/Debug.h"
 
 #include <algorithm>
-#include <regex>
 #include <set>
 
 using namespace llvm;
@@ -482,34 +481,6 @@ CallInst *OCLToSPIRVBase::visitCallAtomicCmpXchg(CallInst *CI) {
     auto Mutator = mutateCallInst(CI, kOCLBuiltinName::AtomicCmpXchgStrong);
     Value *Expected = Mutator.getArg(1);
     Type *MemTy = Mutator.getArg(2)->getType();
-    if (MemTy->isFloatTy() || MemTy->isDoubleTy()) {
-      MemTy =
-          MemTy->isFloatTy() ? Type::getInt32Ty(*Ctx) : Type::getInt64Ty(*Ctx);
-
-      if (!Mutator.getArg(0)->getType()->isOpaquePointerTy()) {
-        TypedPointerType *Arg0PtrType = TypedPointerType::get(
-            MemTy, Mutator.getArg(0)->getType()->getPointerAddressSpace());
-        TypedPointerType *Arg1PtrType = TypedPointerType::get(
-            MemTy, Mutator.getArg(1)->getType()->getPointerAddressSpace());
-
-        Mutator.mapArg(0, [=](IRBuilder<> &Builder, Value *V) {
-          return Builder.CreateBitCast(V, Arg0PtrType);
-        });
-
-        Mutator.mapArg(1, [=](IRBuilder<> &Builder, Value *V) {
-          return Builder.CreateBitCast(V, Arg1PtrType);
-        });
-      }
-
-      Mutator.replaceArg(
-          0,
-          {Mutator.getArg(0),
-           TypedPointerType::get(
-               MemTy, Mutator.getArg(0)->getType()->getPointerAddressSpace())});
-      Mutator.mapArg(2, [=](IRBuilder<> &Builder, Value *V) {
-        return Builder.CreateBitCast(V, MemTy);
-      });
-    }
     assert(MemTy->isIntegerTy() &&
            "In SPIR-V 1.0 arguments of OpAtomicCompareExchange must be "
            "an integer type scalars");
@@ -754,13 +725,6 @@ void OCLToSPIRVBase::visitCallBarrier(CallInst *CI) {
 
 void OCLToSPIRVBase::visitCallConvert(CallInst *CI, StringRef MangledName,
                                       StringRef DemangledName) {
-  // OpenCL Explicit Conversions (6.4.3) formed as below for scalars:
-  // destType convert_destType<_sat><_roundingMode>(sourceType)
-  // and for vector type:
-  // destTypeN convert_destTypeN<_sat><_roundingMode>(sourceTypeN)
-  // If the demangled name is not matching the suggested pattern and does not
-  // meet allowed destination type restrictions - this is not an OpenCL builtin,
-  // return from the function and translate such CallInst as a function call.
   if (eraseUselessConvert(CI, MangledName, DemangledName))
     return;
   Op OC = OpNop;
@@ -772,25 +736,15 @@ void OCLToSPIRVBase::visitCallConvert(CallInst *CI, StringRef MangledName,
     SrcTy = VecTy->getElementType();
   auto IsTargetInt = isa<IntegerType>(TargetTy);
 
-  // Validate conversion function name and vector size if present
-  std::regex Expr(
-      "convert_(float|double|half|u?char|u?short|u?int|u?long)(2|3|4|8|16)*"
-      "(_sat)*(_rt[ezpn])*$");
-  std::smatch DestTyMatch;
-  std::string ConversionFunc(DemangledName.str());
-  if (!std::regex_match(ConversionFunc, DestTyMatch, Expr))
-    return;
-
-  // The first sub_match is the whole string; the next
-  // sub_matches are the parenthesized expressions.
-  enum { TypeIdx = 1, VecSizeIdx = 2, SatIdx = 3, RoundingIdx = 4 };
-  std::string DestTy = DestTyMatch[TypeIdx].str();
-  std::string VecSize = DestTyMatch[VecSizeIdx].str();
-  std::string Sat = DestTyMatch[SatIdx].str();
-  std::string Rounding = DestTyMatch[RoundingIdx].str();
-
-  bool TargetSigned = DestTy[0] != 'u';
+  std::string TargetTyName(
+      DemangledName.substr(strlen(kOCLBuiltinName::ConvertPrefix)));
+  auto FirstUnderscoreLoc = TargetTyName.find('_');
+  if (FirstUnderscoreLoc != std::string::npos)
+    TargetTyName = TargetTyName.substr(0, FirstUnderscoreLoc);
+  TargetTyName = std::string("_R") + TargetTyName;
 
+  std::string Sat = DemangledName.find("_sat") != StringRef::npos ? "_sat" : "";
+  auto TargetSigned = DemangledName[8] != 'u';
   if (isa<IntegerType>(SrcTy)) {
     bool Signed = isLastFuncParamSigned(MangledName);
     if (IsTargetInt) {
@@ -807,10 +761,13 @@ void OCLToSPIRVBase::visitCallConvert(CallInst *CI, StringRef MangledName,
     } else
       OC = OpFConvert;
   }
-
+  auto Loc = DemangledName.find("_rt");
+  std::string Rounding;
+  if (Loc != StringRef::npos && !(isa<IntegerType>(SrcTy) && IsTargetInt)) {
+    Rounding = DemangledName.substr(Loc, 4).str();
+  }
   assert(CI->getCalledFunction() && "Unexpected indirect call");
-  mutateCallInst(
-      CI, getSPIRVFuncName(OC, "_R" + DestTy + VecSize + Sat + Rounding));
+  mutateCallInst(CI, getSPIRVFuncName(OC, TargetTyName + Sat + Rounding));
 }
 
 void OCLToSPIRVBase::visitCallGroupBuiltin(CallInst *CI,
@@ -1180,14 +1137,11 @@ void OCLToSPIRVBase::visitCallRelational(CallInst *CI,
   OCLSPIRVBuiltinMap::find(DemangledName.str(), &OC);
   // i1 or <i1 x N>, depending on whether it returns a vector type.
   Type *BoolTy = CI->getType()->getWithNewType(Type::getInt1Ty(*Ctx));
-  mutateCallInst(CI, OC).changeReturnType(
-      BoolTy, [=](IRBuilder<> &Builder, CallInst *NewCI) {
-        Value *TrueOp = CI->getType()->isVectorTy()
-                            ? Constant::getAllOnesValue(CI->getType())
-                            : getInt32(M, 1);
-        return Builder.CreateSelect(NewCI, TrueOp,
-                                    Constant::getNullValue(CI->getType()));
-      });
+  mutateCallInst(CI, OC).changeReturnType(BoolTy, [=](IRBuilder<> &Builder,
+                                                      CallInst *NewCI) {
+    return Builder.CreateSelect(NewCI, Constant::getAllOnesValue(CI->getType()),
+                                Constant::getNullValue(CI->getType()));
+  });
 }
 
 void OCLToSPIRVBase::visitCallVecLoadStore(CallInst *CI, StringRef MangledName,
