@@ -898,7 +898,6 @@ SPIRAddressSpace getOCLOpaqueTypeAddrSpace(Op OpCode) {
   case OpTypeSampler:
     return SPIRV_SAMPLER_T_ADDR_SPACE;
   case internal::OpTypeJointMatrixINTEL:
-  case OpTypeCooperativeMatrixKHR:
     return SPIRAS_Global;
   default:
     if (isSubgroupAvcINTELTypeOpCode(OpCode))
@@ -1360,9 +1359,6 @@ bool isSamplerTy(Type *Ty) {
     auto *STy = dyn_cast_or_null<StructType>(TPT->getElementType());
     return STy && STy->hasName() && STy->getName() == kSPR2TypeName::Sampler;
   }
-  if (auto *TET = dyn_cast_or_null<TargetExtType>(Ty)) {
-    return TET->getName() == "spirv.Sampler";
-  }
   return false;
 }
 
@@ -1485,8 +1481,8 @@ std::string getIntelSubgroupBlockDataPostfix(unsigned ElementBitSize,
     OSS << VectorNumElements;
     break;
   case 16:
-    assert((ElementBitSize == 8 || ElementBitSize == 16) &&
-           "16 elements vector allowed only for char and short builtins");
+    assert(ElementBitSize == 8 &&
+           "16 elements vector allowed only for char builtins");
     OSS << VectorNumElements;
     break;
   default:
