@@ -98,19 +98,11 @@ enum OCLScopeKind {
 // To avoid any inconsistence here, constants are explicitly initialized with
 // the corresponding constants from 'std::memory_order' enum.
 enum OCLMemOrderKind {
-#if __cplusplus >= 202002L
-  OCLMO_relaxed = static_cast<int>(std::memory_order::relaxed),
-  OCLMO_acquire = static_cast<int>(std::memory_order::acquire),
-  OCLMO_release = static_cast<int>(std::memory_order::release),
-  OCLMO_acq_rel = static_cast<int>(std::memory_order::acq_rel),
-  OCLMO_seq_cst = static_cast<int>(std::memory_order::seq_cst)
-#else
   OCLMO_relaxed = std::memory_order::memory_order_relaxed,
   OCLMO_acquire = std::memory_order::memory_order_acquire,
   OCLMO_release = std::memory_order::memory_order_release,
   OCLMO_acq_rel = std::memory_order::memory_order_acq_rel,
   OCLMO_seq_cst = std::memory_order::memory_order_seq_cst
-#endif
 };
 
 enum IntelFPGAMemoryAccessesVal {
@@ -459,12 +451,11 @@ SmallVector<unsigned, 3> decodeMDNode(MDNode *N);
 template <typename T> std::string getFullPath(const T *Scope) {
   if (!Scope)
     return std::string();
-  StringRef Filename = Scope->getFilename();
-  auto Style = sys::path::Style::native;
-  if (sys::path::is_absolute(Filename, Style))
-    return Filename.str();
+  std::string Filename = Scope->getFilename().str();
+  if (sys::path::is_absolute(Filename))
+    return Filename;
   SmallString<16> DirName = Scope->getDirectory();
-  sys::path::append(DirName, Style, Filename.str());
+  sys::path::append(DirName, sys::path::Style::posix, Filename);
   return DirName.str().str();
 }
 
