@@ -62,9 +62,8 @@ BuiltinCallMutator::BuiltinCallMutator(
     CallInst *CI, std::string FuncName, ManglingRules Rules,
     std::function<std::string(StringRef)> NameMapFn)
     : CI(CI), FuncName(FuncName),
-      Attrs(CI->getCalledFunction()->getAttributes()),
-      CallAttrs(CI->getAttributes()), ReturnTy(CI->getType()), Args(CI->args()),
-      Rules(Rules), Builder(CI) {
+      Attrs(CI->getCalledFunction()->getAttributes()), ReturnTy(CI->getType()),
+      Args(CI->args()), Rules(Rules), Builder(CI) {
   bool DidDemangle = getParameterTypes(CI->getCalledFunction(), PointerTypes,
                                        std::move(NameMapFn));
   if (!DidDemangle) {
@@ -79,8 +78,8 @@ BuiltinCallMutator::BuiltinCallMutator(
 BuiltinCallMutator::BuiltinCallMutator(BuiltinCallMutator &&Other)
     : CI(Other.CI), FuncName(std::move(Other.FuncName)),
       MutateRet(std::move(Other.MutateRet)), Attrs(Other.Attrs),
-      CallAttrs(Other.CallAttrs), ReturnTy(Other.ReturnTy),
-      Args(std::move(Other.Args)), PointerTypes(std::move(Other.PointerTypes)),
+      ReturnTy(Other.ReturnTy), Args(std::move(Other.Args)),
+      PointerTypes(std::move(Other.PointerTypes)),
       Rules(std::move(Other.Rules)), Builder(CI) {
   // Clear the other's CI instance so that it knows not to construct the actual
   // call.
@@ -103,16 +102,6 @@ Value *BuiltinCallMutator::doConversion() {
   CallInst *NewCall =
       Builder.Insert(addCallInst(CI->getModule(), FuncName, ReturnTy, Args,
                                  &Attrs, nullptr, Mangler.get()));
-  NewCall->copyMetadata(*CI);
-  NewCall->setAttributes(CallAttrs);
-  NewCall->setTailCall(CI->isTailCall());
-  if (isa<FPMathOperator>(CI))
-    NewCall->setFastMathFlags(CI->getFastMathFlags());
-
-  if (CI->hasFnAttr("fpbuiltin-max-error")) {
-    auto Attr = CI->getFnAttr("fpbuiltin-max-error");
-    NewCall->addFnAttr(Attr);
-  }
   Value *Result = MutateRet ? MutateRet(Builder, NewCall) : NewCall;
   Result->takeName(CI);
   if (!CI->getType()->isVoidTy())
@@ -127,8 +116,6 @@ BuiltinCallMutator &BuiltinCallMutator::setArgs(ArrayRef<Value *> NewArgs) {
   // Retain only the function attributes, not any parameter attributes.
   Attrs = AttributeList::get(CI->getContext(), Attrs.getFnAttrs(),
                              Attrs.getRetAttrs(), {});
-  CallAttrs = AttributeList::get(CI->getContext(), CallAttrs.getFnAttrs(),
-                                 CallAttrs.getRetAttrs(), {});
   Args.clear();
   PointerTypes.clear();
   for (Value *Arg : NewArgs) {
@@ -182,8 +169,6 @@ BuiltinCallMutator &BuiltinCallMutator::insertArg(unsigned Index,
   PointerTypes.insert(PointerTypes.begin() + Index, Arg.second);
   moveAttributes(CI->getContext(), Attrs, Index, Args.size() - Index,
                  Index + 1);
-  moveAttributes(CI->getContext(), CallAttrs, Index, Args.size() - Index,
-                 Index + 1);
   return *this;
 }
 
@@ -192,21 +177,30 @@ BuiltinCallMutator &BuiltinCallMutator::replaceArg(unsigned Index,
   Args[Index] = Arg.first;
   PointerTypes[Index] = Arg.second;
   Attrs = Attrs.removeParamAttributes(CI->getContext(), Index);
-  CallAttrs = CallAttrs.removeParamAttributes(CI->getContext(), Index);
   return *this;
 }
 
 BuiltinCallMutator &BuiltinCallMutator::removeArg(unsigned Index) {
   // If the argument being dropped is the last one, there is nothing to move, so
   // just remove the attributes.
-  auto &Ctx = CI->getContext();
   if (Index == Args.size() - 1) {
-    Attrs = Attrs.removeParamAttributes(Ctx, Index);
-    CallAttrs = CallAttrs.removeParamAttributes(Ctx, Index);
-  } else {
-    moveAttributes(Ctx, Attrs, Index + 1, Args.size() - Index - 1, Index);
-    moveAttributes(Ctx, CallAttrs, Index + 1, Args.size() - Index - 1, Index);
-  }
+    // TODO: Remove this workaround when LLVM fixes
+    // https://github.com/llvm/llvm-project/issues/59746 on
+    // AttributeList::removeParamAttributes function.
+    // AttributeList::removeParamAttributes function sets attribute at
+    // specified index empty so that return value of
+    // AttributeList::getNumAttrSet() keeps unchanged after that call. When call
+    // BuiltinCallMutator::removeArg function, there is assert failure on
+    // BuiltinCallMutator::doConversion() since new CallInst removed arg but
+    // still holds attribute of that removed arg.
+    SmallVector<AttributeSet, 4> ArgAttrs;
+    for (unsigned I = 0; I < Index; ++I)
+      ArgAttrs.push_back(Attrs.getParamAttrs(I));
+    Attrs = AttributeList::get(CI->getContext(), Attrs.getFnAttrs(),
+                               Attrs.getRetAttrs(), ArgAttrs);
+  } else
+    moveAttributes(CI->getContext(), Attrs, Index + 1, Args.size() - Index - 1,
+                   Index);
   Args.erase(Args.begin() + Index);
   PointerTypes.erase(PointerTypes.begin() + Index);
   return *this;
@@ -285,18 +279,6 @@ Type *BuiltinCallHelper::adjustImageType(Type *T, StringRef OldImageKind,
     }
     return TypedPointerType::get(StructTy, TypedPtrTy->getAddressSpace());
   }
-
-  if (auto *TargetTy = dyn_cast<TargetExtType>(T)) {
-    StringRef Name = TargetTy->getName();
-    if (!Name.consume_front(kSPIRVTypeName::PrefixAndDelim) ||
-        Name != OldImageKind)
-      report_fatal_error("Type did not have expected image kind");
-    return TargetExtType::get(
-        TargetTy->getContext(),
-        (Twine(kSPIRVTypeName::PrefixAndDelim) + NewImageKind).str(),
-        TargetTy->type_params(), TargetTy->int_params());
-  }
-
   report_fatal_error("Expected type to be a SPIRV image type");
 }
 
@@ -325,19 +307,6 @@ Type *BuiltinCallHelper::getSPIRVType(spv::Op TypeOpcode,
                                       StringRef InnerTypeName,
                                       ArrayRef<unsigned> Parameters,
                                       bool UseRealType) {
-  if (UseTargetTypes) {
-    std::string BaseName = (Twine(kSPIRVTypeName::PrefixAndDelim) +
-                            SPIRVOpaqueTypeOpCodeMap::rmap(TypeOpcode))
-                               .str();
-    SmallVector<Type *, 1> TypeParams;
-    if (!InnerTypeName.empty()) {
-      TypeParams.push_back(getLLVMTypeForSPIRVImageSampledTypePostfix(
-          InnerTypeName, M->getContext()));
-    }
-    return TargetExtType::get(M->getContext(), BaseName, TypeParams,
-                              Parameters);
-  }
-
   std::string FullName;
   {
     raw_string_ostream OS(FullName);
@@ -359,23 +328,6 @@ Type *BuiltinCallHelper::getSPIRVType(spv::Op TypeOpcode,
                      : TypedPointerType::get(STy, AddrSpace);
 }
 
-void BuiltinCallHelper::initialize(llvm::Module &M) {
-  this->M = &M;
-  // We want to use pointers-to-opaque-structs for the special types if:
-  // * We are translating from SPIR-V to LLVM IR (which means we are using
-  //   OpenCL mangling rules)
-  // * There are %opencl.* or %spirv.* struct type names already present.
-  UseTargetTypes = Rules != ManglingRules::OpenCL;
-  for (StructType *Ty : M.getIdentifiedStructTypes()) {
-    if (!Ty->isOpaque() || !Ty->hasName())
-      continue;
-    StringRef Name = Ty->getName();
-    if (Name.startswith("opencl.") || Name.startswith("spirv.")) {
-      UseTargetTypes = false;
-    }
-  }
-}
-
 BuiltinCallMutator::ValueTypePair
 BuiltinCallHelper::getCallValue(CallInst *CI, unsigned ArgNo) {
   Function *CalledFunc = CI->getCalledFunction();
