@@ -70,11 +70,7 @@ public:
   template <typename T = MDNode>
   T *transDebugInst(const SPIRVExtInst *DebugInst) {
     assert((DebugInst->getExtSetKind() == SPIRVEIS_Debug ||
-            DebugInst->getExtSetKind() == SPIRVEIS_OpenCL_DebugInfo_100 ||
-            DebugInst->getExtSetKind() ==
-                SPIRVEIS_NonSemantic_Shader_DebugInfo_100 ||
-            DebugInst->getExtSetKind() ==
-                SPIRVEIS_NonSemantic_Shader_DebugInfo_200) &&
+            DebugInst->getExtSetKind() == SPIRVEIS_OpenCL_DebugInfo_100) &&
            "Unexpected extended instruction set");
     auto It = DebugInstCache.find(DebugInst);
     if (It != DebugInstCache.end())
@@ -83,37 +79,27 @@ public:
     DebugInstCache[DebugInst] = Res;
     return static_cast<T *>(Res);
   }
-
   Instruction *transDebugIntrinsic(const SPIRVExtInst *DebugInst,
                                    BasicBlock *BB);
   void finalize();
 
 private:
   DIFile *getFile(const SPIRVId SourceId);
-
-  DIFile *getDIFile(const std::string &FileName,
-                    std::optional<DIFile::ChecksumInfo<StringRef>> CS = std::nullopt,
-                    std::optional<std::string> Source = std::nullopt);
+  DIFile *
+  getDIFile(const std::string &FileName,
+            std::optional<DIFile::ChecksumInfo<StringRef>> CS = std::nullopt);
   DIFile *getDIFile(const SPIRVEntry *E);
   unsigned getLineNo(const SPIRVEntry *E);
 
   MDNode *transDebugInstImpl(const SPIRVExtInst *DebugInst);
 
-  DIType *transNonNullDebugType(const SPIRVExtInst *DebugInst);
-
   llvm::DebugLoc transDebugLocation(const SPIRVExtInst *DebugInst);
 
   llvm::DebugLoc transDebugScope(const SPIRVInstruction *Inst);
 
   MDNode *transDebugInlined(const SPIRVExtInst *Inst);
-  MDNode *transDebugInlinedNonSemanticShader200(const SPIRVExtInst *Inst);
 
-  void appendToSourceLangLiteral(DICompileUnit *CompileUnit,
-                                 SPIRVWord SourceLang);
-
-  DICompileUnit *transCompilationUnit(const SPIRVExtInst *DebugInst,
-                                      const std::string CompilerVersion = "",
-                                      const std::string Flags = "");
+  DICompileUnit *transCompileUnit(const SPIRVExtInst *DebugInst);
 
   DIBasicType *transTypeBasic(const SPIRVExtInst *DebugInst);
 
@@ -122,33 +108,20 @@ private:
   DIType *transTypePointer(const SPIRVExtInst *DebugInst);
 
   DICompositeType *transTypeArray(const SPIRVExtInst *DebugInst);
-  DICompositeType *transTypeArrayOpenCL(const SPIRVExtInst *DebugInst);
-  DICompositeType *transTypeArrayNonSemantic(const SPIRVExtInst *DebugInst);
-  DICompositeType *transTypeArrayDynamic(const SPIRVExtInst *DebugInst);
 
   DICompositeType *transTypeVector(const SPIRVExtInst *DebugInst);
 
   DICompositeType *transTypeComposite(const SPIRVExtInst *DebugInst);
 
-  DISubrange *transTypeSubrange(const SPIRVExtInst *DebugInst);
-
-  DIStringType *transTypeString(const SPIRVExtInst *DebugInst);
-
-  DINode *transTypeMember(const SPIRVExtInst *DebugInst,
-                          const SPIRVExtInst *ParentInst = nullptr,
-                          DIScope *Scope = nullptr);
-  DINode *transTypeMemberOpenCL(const SPIRVExtInst *DebugInst);
-  DINode *transTypeMemberNonSemantic(const SPIRVExtInst *DebugInst,
-                                     const SPIRVExtInst *ParentInst,
-                                     DIScope *Scope);
+  DINode *transTypeMember(const SPIRVExtInst *DebugInst);
 
   DINode *transTypeEnum(const SPIRVExtInst *DebugInst);
 
-  DINode *transTypeTemplateParameter(const SPIRVExtInst *DebugInst);
-  DINode *transTypeTemplateTemplateParameter(const SPIRVExtInst *DebugInst);
-  DINode *transTypeTemplateParameterPack(const SPIRVExtInst *DebugInst);
+  DINode *transTemplateParameter(const SPIRVExtInst *DebugInst);
+  DINode *transTemplateTemplateParameter(const SPIRVExtInst *DebugInst);
+  DINode *transTemplateParameterPack(const SPIRVExtInst *DebugInst);
 
-  MDNode *transTypeTemplate(const SPIRVExtInst *DebugInst);
+  MDNode *transTemplate(const SPIRVExtInst *DebugInst);
 
   DINode *transTypeFunction(const SPIRVExtInst *DebugInst);
 
@@ -157,23 +130,17 @@ private:
   DINode *transLexicalBlock(const SPIRVExtInst *DebugInst);
   DINode *transLexicalBlockDiscriminator(const SPIRVExtInst *DebugInst);
 
-  DINode *transFunction(const SPIRVExtInst *DebugInst,
-                        bool IsMainSubprogram = false);
-  DINode *transFunctionDefinition(const SPIRVExtInst *DebugInst);
-  void transFunctionBody(DISubprogram *DIS, SPIRVId FuncId);
+  DINode *transFunction(const SPIRVExtInst *DebugInst);
 
   DINode *transFunctionDecl(const SPIRVExtInst *DebugInst);
 
-  MDNode *transEntryPoint(const SPIRVExtInst *DebugInst);
-
   MDNode *transGlobalVariable(const SPIRVExtInst *DebugInst);
 
   DINode *transLocalVariable(const SPIRVExtInst *DebugInst);
 
   DINode *transTypedef(const SPIRVExtInst *DebugInst);
 
-  DINode *transTypeInheritance(const SPIRVExtInst *DebugInst,
-                               DIType *ChildClass = nullptr);
+  DINode *transInheritance(const SPIRVExtInst *DebugInst);
 
   DINode *transImportedEntry(const SPIRVExtInst *DebugInst);
 
@@ -183,7 +150,7 @@ private:
 
   SPIRVModule *BM;
   Module *M;
-  std::unordered_map<SPIRVId, std::unique_ptr<DIBuilder>> BuilderMap;
+  DIBuilder Builder;
   SPIRVToLLVM *SPIRVReader;
   bool Enable;
   std::unordered_map<std::string, DIFile *> FileMap;
@@ -199,8 +166,6 @@ private:
   DIScope *getScope(const SPIRVEntry *ScopeInst);
   SPIRVExtInst *getDbgInst(const SPIRVId Id);
 
-  DIBuilder &getDIBuilder(const SPIRVExtInst *DebugInst);
-
   template <SPIRVWord OpCode> SPIRVExtInst *getDbgInst(const SPIRVId Id) {
     if (SPIRVExtInst *DI = getDbgInst(Id)) {
       if (DI->getExtOp() == OpCode) {
@@ -210,19 +175,8 @@ private:
     return nullptr;
   }
   const std::string &getString(const SPIRVId Id);
-  std::optional<std::string> getStringSourceContinued(const SPIRVId Id,
-                                                      SPIRVExtInst *DebugInst);
-  SPIRVWord getConstantValueOrLiteral(const std::vector<SPIRVWord> &,
-                                      const SPIRVWord,
-                                      const SPIRVExtInstSetKind);
   std::string findModuleProducer();
   std::optional<DIFile::ChecksumInfo<StringRef>> ParseChecksum(StringRef Text);
-
-  // BuildIdentifier and StoragePath must both be set or both unset.
-  // If StoragePath is empty both variables are unset and not valid.
-  uint64_t BuildIdentifier{0};
-  std::string StoragePath{};
-  void setBuildIdentifierAndStoragePath();
 };
 } // namespace SPIRV
 
