@@ -94,24 +94,6 @@ void removeFnAttr(CallInst *Call, Attribute::AttrKind Attr) {
   Call->removeFnAttr(Attr);
 }
 
-Value *extendVector(Value *V, FixedVectorType *NewType,
-                    IRBuilderBase &Builder) {
-  unsigned OldSize = cast<FixedVectorType>(V->getType())->getNumElements();
-  unsigned NewSize = NewType->getNumElements();
-  assert(OldSize < NewSize);
-  std::vector<Constant *> Components;
-  IntegerType *Int32Ty = Builder.getInt32Ty();
-  for (unsigned I = 0; I < NewSize; I++) {
-    if (I < OldSize)
-      Components.push_back(ConstantInt::get(Int32Ty, I));
-    else
-      Components.push_back(PoisonValue::get(Int32Ty));
-  }
-
-  return Builder.CreateShuffleVector(V, PoisonValue::get(V->getType()),
-                                     ConstantVector::get(Components), "vecext");
-}
-
 void saveLLVMModule(Module *M, const std::string &OutputFile) {
   std::error_code EC;
   ToolOutputFile Out(OutputFile.c_str(), EC, sys::fs::OF_None);
@@ -188,7 +170,7 @@ StructType *getOrCreateOpaqueStructType(Module *M, StringRef Name) {
 }
 
 void getFunctionTypeParameterTypes(llvm::FunctionType *FT,
-                                   SmallVector<Type *> &ArgTys) {
+                                   std::vector<Type *> &ArgTys) {
   for (auto I = FT->param_begin(), E = FT->param_end(); I != E; ++I) {
     ArgTys.push_back(*I);
   }
@@ -207,10 +189,6 @@ bool isOCLImageType(llvm::Type *Ty, StringRef *Name) {
           return true;
         }
       }
-  if (auto *TET = dyn_cast_or_null<TargetExtType>(Ty)) {
-    assert(!Name && "Cannot get the name for a target-extension type image");
-    return TET->getName() == "spirv.Image";
-  }
   return false;
 }
 /// \param BaseTyName is the type Name as in spirv.BaseTyName.Postfixes
@@ -551,11 +529,6 @@ ParamType lastFuncParamType(StringRef MangledName) {
   char Mangled = Copy.back();
   std::string Mangled2 = Copy.substr(Copy.size() - 2);
 
-  std::string Mangled5 = Copy.substr(Copy.size() - 5);
-  if (Mangled5 == "DF16b") {
-    return ParamType::FLOAT;
-  }
-
   if (isMangledTypeFP(Mangled) || isMangledTypeHalf(Mangled2)) {
     return ParamType::FLOAT;
   } else if (isMangledTypeUnsigned(Mangled)) {
@@ -642,21 +615,6 @@ static Type *parsePrimitiveType(LLVMContext &Ctx, StringRef Name) {
 
 } // namespace SPIRV
 
-namespace {
-
-// Return the value for when the dimension index of a builtin is out of range.
-uint64_t getBuiltinOutOfRangeValue(StringRef VarName) {
-  assert(VarName.startswith("__spirv_BuiltIn"));
-  return StringSwitch<uint64_t>(VarName)
-      .EndsWith("GlobalSize", 1)
-      .EndsWith("NumWorkgroups", 1)
-      .EndsWith("WorkgroupSize", 1)
-      .EndsWith("EnqueuedWorkgroupSize", 1)
-      .Default(0);
-}
-
-} // anonymous namespace
-
 // The demangler node hierarchy doesn't use LLVM's RTTI helper functions (as it
 // also needs to live in libcxxabi). By specializing this implementation here,
 // we can add support for these functions.
@@ -695,37 +653,6 @@ static StringRef stringify(const itanium_demangle::NameType *Node) {
   return StringRef(Str.begin(), Str.size());
 }
 
-/// Convert a mangled name that represents a basic integer, floating-point,
-/// etc. type into the corresponding LLVM type.
-static Type *getPrimitiveType(LLVMContext &Ctx,
-                              const llvm::itanium_demangle::Node *N) {
-  using namespace llvm::itanium_demangle;
-  if (auto *Name = dyn_cast<NameType>(N)) {
-    return parsePrimitiveType(Ctx, stringify(Name));
-  }
-  if (auto *BitInt = dyn_cast<BitIntType>(N)) {
-    unsigned BitWidth = 0;
-    BitInt->match([&](const Node *NodeSize, bool) {
-      const StringRef SizeStr(stringify(cast<NameType>(NodeSize)));
-      SizeStr.getAsInteger(10, BitWidth);
-    });
-    return Type::getIntNTy(Ctx, BitWidth);
-  }
-  if (auto *FP = dyn_cast<BinaryFPType>(N)) {
-    StringRef SizeStr;
-    FP->match([&](const Node *NodeDimension) {
-      SizeStr = stringify(cast<NameType>(NodeDimension));
-    });
-    return StringSwitch<Type *>(SizeStr)
-        .Case("16", Type::getHalfTy(Ctx))
-        .Case("32", Type::getFloatTy(Ctx))
-        .Case("64", Type::getDoubleTy(Ctx))
-        .Case("128", Type::getFP128Ty(Ctx))
-        .Default(nullptr);
-  }
-  return nullptr;
-}
-
 template <typename FnType>
 static TypedPointerType *
 parseNode(Module *M, const llvm::itanium_demangle::Node *ParamType,
@@ -797,15 +724,21 @@ parseNode(Module *M, const llvm::itanium_demangle::Node *ParamType,
       } else {
         PointeeTy = parsePrimitiveType(M->getContext(), MangledStructName);
       }
-    } else if (auto *Ty = getPrimitiveType(M->getContext(), Pointee)) {
-      PointeeTy = Ty;
+    } else if (auto *BitInt = dyn_cast<BitIntType>(Pointee)) {
+      unsigned BitWidth = 0;
+      BitInt->match([&](const Node *NodeSize, bool) {
+        const StringRef SizeStr(stringify(cast<NameType>(NodeSize)));
+        SizeStr.getAsInteger(10, BitWidth);
+      });
+      PointeeTy = Type::getIntNTy(M->getContext(), BitWidth);
     } else if (auto *Vec = dyn_cast<itanium_demangle::VectorType>(Pointee)) {
       unsigned ElemCount = 0;
       const StringRef ElemCountStr(
           stringify(cast<NameType>(Vec->getDimension())));
       ElemCountStr.getAsInteger(10, ElemCount);
-      if (auto *Ty = getPrimitiveType(M->getContext(), Vec->getBaseType())) {
-        PointeeTy = llvm::VectorType::get(Ty, ElemCount, false);
+      if (auto *Name = dyn_cast<NameType>(Vec->getBaseType())) {
+        PointeeTy = parsePrimitiveType(M->getContext(), stringify(Name));
+        PointeeTy = llvm::VectorType::get(PointeeTy, ElemCount, false);
       }
     } else if (llvm::isa<itanium_demangle::PointerType>(Pointee)) {
       PointeeTy = parseNode(M, Pointee, GetStructType);
@@ -854,12 +787,11 @@ bool getParameterTypes(Function *F, SmallVectorImpl<Type *> &ArgTys,
       assert(!HasSret && &Arg == F->getArg(0) &&
              "sret parameter should only appear on the first argument");
       HasSret = true;
-      unsigned AS = Arg.getType()->getPointerAddressSpace();
       if (auto *STy = dyn_cast<StructType>(Ty))
         ArgTys.push_back(
-            TypedPointerType::get(GetStructType(STy->getName()), AS));
+            TypedPointerType::get(GetStructType(STy->getName()), 0));
       else
-        ArgTys.push_back(TypedPointerType::get(Ty, AS));
+        ArgTys.push_back(TypedPointerType::get(Ty, 0));
     } else {
       ArgTys.push_back(Arg.getType());
     }
@@ -928,13 +860,8 @@ bool getParameterTypes(Function *F, SmallVectorImpl<Type *> &ArgTys,
       LLVM_DEBUG(dbgs() << "Failed to recover type of argument " << *ArgTy
                         << " of function " << F->getName() << "\n");
       DemangledSuccessfully = false;
-    } else if (ArgTy->isTargetExtTy() || !DemangledTy)
+    } else if (!DemangledTy)
       DemangledTy = ArgTy;
-    if (auto *TPT = dyn_cast<TypedPointerType>(DemangledTy))
-      if (ArgTy->isPointerTy() &&
-          TPT->getAddressSpace() != ArgTy->getPointerAddressSpace())
-        DemangledTy = TypedPointerType::get(TPT->getElementType(),
-                                            ArgTy->getPointerAddressSpace());
     *ArgIter++ = DemangledTy;
   }
   return DemangledSuccessfully;
@@ -1352,8 +1279,6 @@ static SPIR::RefParamType transTypeDesc(Type *Ty,
     return SPIR::RefParamType(new SPIR::PrimitiveType(SPIR::PRIMITIVE_FLOAT));
   if (Ty->isDoubleTy())
     return SPIR::RefParamType(new SPIR::PrimitiveType(SPIR::PRIMITIVE_DOUBLE));
-  if (Ty->isBFloatTy())
-    return SPIR::RefParamType(new SPIR::PrimitiveType(SPIR::PRIMITIVE_BFLOAT));
   if (auto *VecTy = dyn_cast<FixedVectorType>(Ty)) {
     return SPIR::RefParamType(new SPIR::VectorType(
         transTypeDesc(VecTy->getElementType(), Info), VecTy->getNumElements()));
@@ -1386,61 +1311,6 @@ static SPIR::RefParamType transTypeDesc(Type *Ty,
     }
     return SPIR::RefParamType(new SPIR::UserDefinedType(Name.str()));
   }
-  if (auto *TargetTy = dyn_cast<TargetExtType>(Ty)) {
-    std::string FullName;
-    unsigned AS = 0;
-    {
-      raw_string_ostream OS(FullName);
-      StringRef Name = TargetTy->getName();
-      if (Name.consume_front(kSPIRVTypeName::PrefixAndDelim)) {
-        OS << "__spirv_" << Name;
-        AS = getOCLOpaqueTypeAddrSpace(
-            SPIRVOpaqueTypeOpCodeMap::map(Name.str()));
-      } else {
-        OS << Name;
-      }
-      if (!TargetTy->int_params().empty())
-        OS << "_";
-      for (Type *InnerTy : TargetTy->type_params())
-        OS << "_" << convertTypeToPostfix(InnerTy);
-      for (unsigned Param : TargetTy->int_params())
-        OS << "_" << Param;
-    }
-    // Translate as if it's a pointer to the named struct.
-    auto *Inner = new SPIR::UserDefinedType(FullName);
-    auto *PT = new SPIR::PointerType(Inner);
-    PT->setAddressSpace(static_cast<SPIR::TypeAttributeEnum>(
-        AS + (unsigned)SPIR::ATTR_ADDR_SPACE_FIRST));
-    return SPIR::RefParamType(PT);
-  }
-
-  if (auto *TargetTy = dyn_cast<TargetExtType>(Ty)) {
-    std::string FullName;
-    unsigned AS = 0;
-    {
-      raw_string_ostream OS(FullName);
-      StringRef Name = TargetTy->getName();
-      if (Name.consume_front(kSPIRVTypeName::PrefixAndDelim)) {
-        OS << "__spirv_" << Name;
-        AS = getOCLOpaqueTypeAddrSpace(
-            SPIRVOpaqueTypeOpCodeMap::map(Name.str()));
-      } else {
-        OS << Name;
-      }
-      if (!TargetTy->int_params().empty())
-        OS << "_";
-      for (Type *InnerTy : TargetTy->type_params())
-        OS << "_" << convertTypeToPostfix(InnerTy);
-      for (unsigned Param : TargetTy->int_params())
-        OS << "_" << Param;
-    }
-    // Translate as if it's a pointer to the named struct.
-    auto *Inner = new SPIR::UserDefinedType(FullName);
-    auto *PT = new SPIR::PointerType(Inner);
-    PT->setAddressSpace(static_cast<SPIR::TypeAttributeEnum>(
-        AS + (unsigned)SPIR::ATTR_ADDR_SPACE_FIRST));
-    return SPIR::RefParamType(PT);
-  }
 
   if (auto *TPT = dyn_cast<TypedPointerType>(Ty)) {
     auto *ET = TPT->getElementType();
@@ -1639,9 +1509,6 @@ Type *getLLVMTypeForSPIRVImageSampledTypePostfix(StringRef Postfix,
   if (Postfix == kSPIRVImageSampledTypeName::Int ||
       Postfix == kSPIRVImageSampledTypeName::UInt)
     return Type::getInt32Ty(Ctx);
-  if (Postfix == kSPIRVImageSampledTypeName::Long ||
-      Postfix == kSPIRVImageSampledTypeName::ULong)
-    return Type::getInt64Ty(Ctx);
   llvm_unreachable("Invalid sampled type postfix");
   return nullptr;
 }
@@ -1693,26 +1560,7 @@ std::string getImageBaseTypeName(StringRef Name) {
   return ImageTyName;
 }
 
-size_t getImageOperandsIndex(Op OpCode) {
-  switch (OpCode) {
-  case OpImageRead:
-  case OpImageSampleExplicitLod:
-    return 2;
-  case OpImageWrite:
-    return 3;
-  default:
-    return ~0U;
-  }
-}
-
 SPIRVTypeImageDescriptor getImageDescriptor(Type *Ty) {
-  if (auto *TET = dyn_cast_or_null<TargetExtType>(Ty)) {
-    auto IntParams = TET->int_params();
-    assert(IntParams.size() > 6 && "Expected type to be an image type");
-    return SPIRVTypeImageDescriptor(SPIRVImageDimKind(IntParams[0]),
-                                    IntParams[1], IntParams[2], IntParams[3],
-                                    IntParams[4], IntParams[5]);
-  }
   StringRef TyName;
   [[maybe_unused]] bool IsImg = isOCLImageType(Ty, &TyName);
   assert(IsImg && "Must be an image type");
@@ -1971,9 +1819,6 @@ bool checkTypeForSPIRVExtendedInstLowering(IntrinsicInst *II, SPIRVModule *BM) {
       NumElems = VecTy->getNumElements();
       Ty = VecTy->getElementType();
     }
-    if (Ty->isBFloatTy() &&
-        BM->hasCapability(internal::CapabilityBFloat16ArithmeticINTEL))
-      return true;
     if ((!Ty->isFloatTy() && !Ty->isDoubleTy() && !Ty->isHalfTy()) ||
         (!BM->hasCapability(CapabilityVectorAnyINTEL) &&
          ((NumElems > 4) && (NumElems != 8) && (NumElems != 16)))) {
@@ -1990,9 +1835,6 @@ bool checkTypeForSPIRVExtendedInstLowering(IntrinsicInst *II, SPIRVModule *BM) {
       NumElems = VecTy->getNumElements();
       Ty = VecTy->getElementType();
     }
-    if (Ty->isBFloatTy() &&
-        BM->hasCapability(internal::CapabilityBFloat16ArithmeticINTEL))
-      return true;
     if ((!Ty->isIntegerTy()) ||
         (!BM->hasCapability(CapabilityVectorAnyINTEL) &&
          ((NumElems > 4) && (NumElems != 8) && (NumElems != 16)))) {
@@ -2007,15 +1849,14 @@ bool checkTypeForSPIRVExtendedInstLowering(IntrinsicInst *II, SPIRVModule *BM) {
   return true;
 }
 
-CallInst *setAttrByCalledFunc(CallInst *Call) {
+void setAttrByCalledFunc(CallInst *Call) {
   Function *F = Call->getCalledFunction();
   assert(F);
   if (F->isIntrinsic()) {
-    return Call;
+    return;
   }
   Call->setCallingConv(F->getCallingConv());
   Call->setAttributes(F->getAttributes());
-  return Call;
 }
 
 bool isSPIRVBuiltinVariable(GlobalVariable *GV,
@@ -2065,94 +1906,6 @@ bool isSPIRVBuiltinVariable(GlobalVariable *GV,
 // %4 = call spir_func i64 @_Z13get_global_idj(i32 2) #1
 // %5 = insertelement <3 x i64> %3, i64 %4, i32 2
 // %6 = extractelement <3 x i64> %5, i32 0
-
-/// Recursively look through the uses of a global variable, including casts or
-/// gep offsets, to find all loads of the variable. Gep offsets that are non-0
-/// are accumulated in the AccumulatedOffset parameter, which will eventually be
-/// used to figure out which index of a variable is being used.
-static void replaceUsesOfBuiltinVar(Value *V, const APInt &AccumulatedOffset,
-                                    Function *ReplacementFunc,
-                                    GlobalVariable *GV) {
-  const DataLayout &DL = ReplacementFunc->getParent()->getDataLayout();
-  SmallVector<Instruction *, 4> InstsToRemove;
-  for (User *U : V->users()) {
-    if (auto *Cast = dyn_cast<CastInst>(U)) {
-      replaceUsesOfBuiltinVar(Cast, AccumulatedOffset, ReplacementFunc, GV);
-      InstsToRemove.push_back(Cast);
-    } else if (auto *GEP = dyn_cast<GetElementPtrInst>(U)) {
-      APInt NewOffset = AccumulatedOffset.sextOrTrunc(
-          DL.getIndexSizeInBits(GEP->getPointerAddressSpace()));
-      if (!GEP->accumulateConstantOffset(DL, NewOffset))
-        llvm_unreachable("Illegal GEP of a SPIR-V builtin variable");
-      replaceUsesOfBuiltinVar(GEP, NewOffset, ReplacementFunc, GV);
-      InstsToRemove.push_back(GEP);
-    } else if (auto *Load = dyn_cast<LoadInst>(U)) {
-      // Figure out which index the accumulated offset corresponds to. If we
-      // have a weird offset (e.g., trying to load byte 7), bail out.
-      Type *ScalarTy = ReplacementFunc->getReturnType();
-      APInt Index;
-      uint64_t Remainder;
-      APInt::udivrem(AccumulatedOffset, ScalarTy->getScalarSizeInBits() / 8,
-                     Index, Remainder);
-      if (Remainder != 0)
-        llvm_unreachable("Illegal GEP of a SPIR-V builtin variable");
-
-      IRBuilder<> Builder(Load);
-      Value *Replacement;
-      if (ReplacementFunc->getFunctionType()->getNumParams() == 0) {
-        if (Load->getType() != ScalarTy)
-          llvm_unreachable("Illegal use of a SPIR-V builtin variable");
-        Replacement =
-            setAttrByCalledFunc(Builder.CreateCall(ReplacementFunc, {}));
-      } else {
-        // The function has an index parameter.
-        if (auto *VecTy = dyn_cast<FixedVectorType>(Load->getType())) {
-          // Reconstruct the original global variable vector because
-          // the load type may not match.
-          // global <3 x i64>, load <6 x i32>
-          VecTy = cast<FixedVectorType>(GV->getValueType());
-          if (!Index.isZero() || DL.getTypeSizeInBits(VecTy) !=
-                                     DL.getTypeSizeInBits(Load->getType()))
-            llvm_unreachable("Illegal use of a SPIR-V builtin variable");
-          Replacement = UndefValue::get(VecTy);
-          for (unsigned I = 0; I < VecTy->getNumElements(); I++) {
-            Replacement = Builder.CreateInsertElement(
-                Replacement,
-                setAttrByCalledFunc(
-                    Builder.CreateCall(ReplacementFunc, {Builder.getInt32(I)})),
-                Builder.getInt32(I));
-          }
-          // Insert a bitcast from the reconstructed vector to the load vector
-          // type in case they are different.
-          // Input:
-          // %1 = load <6 x i32>, ptr addrspace(1) %0, align 32
-          // %2 = extractelement <6 x i32> %1, i32 0
-          // %3 = add i32 5, %2
-          // Modified:
-          // < reconstruct global vector elements 0 and 1 >
-          // %2 = insertelement <3 x i64> %0, i64 %1, i32 2
-          // %3 = bitcast <3 x i64> %2 to <6 x i32>
-          // %4 = extractelement <6 x i32> %3, i32 0
-          // %5 = add i32 5, %4
-          Replacement = Builder.CreateBitCast(Replacement, Load->getType());
-        } else if (Load->getType() == ScalarTy) {
-          Replacement = setAttrByCalledFunc(Builder.CreateCall(
-              ReplacementFunc, {Builder.getInt32(Index.getZExtValue())}));
-        } else {
-          llvm_unreachable("Illegal load type of a SPIR-V builtin variable");
-        }
-      }
-      Load->replaceAllUsesWith(Replacement);
-      InstsToRemove.push_back(Load);
-    } else {
-      llvm_unreachable("Illegal use of a SPIR-V builtin variable");
-    }
-  }
-
-  for (Instruction *I : InstsToRemove)
-    I->eraseFromParent();
-}
-
 bool lowerBuiltinVariableToCall(GlobalVariable *GV,
                                 SPIRVBuiltinVariableKind Kind) {
   // There might be dead constant users of GV (for example, SPIRVLowerConstExpr
@@ -2188,7 +1941,113 @@ bool lowerBuiltinVariableToCall(GlobalVariable *GV,
     Func->setDoesNotAccessMemory();
   }
 
-  replaceUsesOfBuiltinVar(GV, APInt(64, 0), Func, GV);
+  // Collect instructions in these containers to remove them later.
+  std::vector<Instruction *> Loads;
+  std::vector<Instruction *> Casts;
+  std::vector<Instruction *> GEPs;
+
+  auto Replace = [&](std::vector<Value *> Arg, Instruction *I) {
+    auto *Call = CallInst::Create(Func, Arg, "", I);
+    Call->takeName(I);
+    setAttrByCalledFunc(Call);
+    SPIRVDBG(dbgs() << "[lowerBuiltinVariableToCall] " << *I << " -> " << *Call
+                    << '\n';)
+    I->replaceAllUsesWith(Call);
+  };
+
+  // If HasIndexArg is true, we create 3 built-in calls and insertelement to
+  // get 3-element vector filled with ids and replace uses of Load instruction
+  // with this vector.
+  // If HasIndexArg is false, the result of the Load instruction is the value
+  // which should be replaced with the Func.
+  // Returns true if Load was replaced, false otherwise.
+  auto ReplaceIfLoad = [&](User *I) {
+    auto *LD = dyn_cast<LoadInst>(I);
+    if (!LD)
+      return false;
+    std::vector<Value *> Vectors;
+    Loads.push_back(LD);
+    if (HasIndexArg) {
+      auto *VecTy = cast<FixedVectorType>(GVTy);
+      Value *EmptyVec = UndefValue::get(VecTy);
+      Vectors.push_back(EmptyVec);
+      const DebugLoc &DLoc = LD->getDebugLoc();
+      for (unsigned I = 0; I < VecTy->getNumElements(); ++I) {
+        auto *Idx = ConstantInt::get(Type::getInt32Ty(C), I);
+        auto *Call = CallInst::Create(Func, {Idx}, "", LD);
+        if (DLoc)
+          Call->setDebugLoc(DLoc);
+        setAttrByCalledFunc(Call);
+        auto *Insert = InsertElementInst::Create(Vectors.back(), Call, Idx);
+        if (DLoc)
+          Insert->setDebugLoc(DLoc);
+        Insert->insertAfter(Call);
+        Vectors.push_back(Insert);
+      }
+
+      Value *Ptr = LD->getPointerOperand();
+
+      if (isa<FixedVectorType>(LD->getType())) {
+        LD->replaceAllUsesWith(Vectors.back());
+      } else {
+        auto *GEP = dyn_cast<GetElementPtrInst>(Ptr);
+        assert(GEP && "Unexpected pattern!");
+        assert(GEP->getNumIndices() == 2 && "Unexpected pattern!");
+        Value *Idx = GEP->getOperand(2);
+        Value *Vec = Vectors.back();
+        auto *NewExtract = ExtractElementInst::Create(Vec, Idx);
+        NewExtract->insertAfter(cast<Instruction>(Vec));
+        LD->replaceAllUsesWith(NewExtract);
+      }
+
+    } else {
+      Replace({}, LD);
+    }
+
+    return true;
+  };
+
+  // Go over the GV users, find Load and ExtractElement instructions and
+  // replace them with the corresponding function call.
+  for (auto *UI : GV->users()) {
+    // There might or might not be an addrspacecast instruction.
+    if (auto *ASCast = dyn_cast<AddrSpaceCastInst>(UI)) {
+      Casts.push_back(ASCast);
+      for (auto *CastUser : ASCast->users()) {
+        if (ReplaceIfLoad(CastUser))
+          continue;
+        if (auto *GEP = dyn_cast<GetElementPtrInst>(CastUser)) {
+          GEPs.push_back(GEP);
+          for (auto *GEPUser : GEP->users()) {
+            if (!ReplaceIfLoad(GEPUser))
+              llvm_unreachable("Unexpected pattern!");
+          }
+        } else {
+          llvm_unreachable("Unexpected pattern!");
+        }
+      }
+    } else if (auto *GEP = dyn_cast<GetElementPtrInst>(UI)) {
+      GEPs.push_back(GEP);
+      for (auto *GEPUser : GEP->users()) {
+        if (!ReplaceIfLoad(GEPUser))
+          llvm_unreachable("Unexpected pattern!");
+      }
+    } else if (!ReplaceIfLoad(UI)) {
+      llvm_unreachable("Unexpected pattern!");
+    }
+  }
+
+  auto Erase = [](std::vector<Instruction *> &ToErase) {
+    for (Instruction *I : ToErase) {
+      assert(I->hasNUses(0));
+      I->eraseFromParent();
+    }
+  };
+  // Order of erasing is important.
+  Erase(Loads);
+  Erase(GEPs);
+  Erase(Casts);
+
   return true;
 }
 
@@ -2209,110 +2068,6 @@ bool lowerBuiltinVariablesToCalls(Module *M) {
   return true;
 }
 
-/// Transforms SPV-IR work-item builtin calls to SPIRV builtin variables.
-/// e.g.
-///  SPV-IR: @_Z33__spirv_BuiltInGlobalInvocationIdi(i)
-///    is transformed as:
-///  x = load GlobalInvocationId; extract x, i
-/// e.g.
-///  SPV-IR: @_Z22__spirv_BuiltInWorkDim()
-///    is transformed as:
-///  load WorkDim
-bool lowerBuiltinCallsToVariables(Module *M) {
-  LLVM_DEBUG(dbgs() << "Enter lowerBuiltinCallsToVariables\n");
-  // Store instructions and functions that need to be removed.
-  SmallVector<Value *, 16> ToRemove;
-  for (auto &F : *M) {
-    // Builtins should be declaration only.
-    if (!F.isDeclaration())
-      continue;
-    StringRef DemangledName;
-    if (!oclIsBuiltin(F.getName(), DemangledName))
-      continue;
-    LLVM_DEBUG(dbgs() << "Function demangled name: " << DemangledName << '\n');
-    SmallVector<StringRef, 2> Postfix;
-    // Deprefix "__spirv_"
-    StringRef Name = dePrefixSPIRVName(DemangledName, Postfix);
-    // Lookup SPIRV Builtin map.
-    if (!SPIRVBuiltInNameMap::rfind(Name.str(), nullptr))
-      continue;
-    std::string BuiltinVarName = DemangledName.str();
-    LLVM_DEBUG(dbgs() << "builtin variable name: " << BuiltinVarName << '\n');
-    bool IsVec = F.getFunctionType()->getNumParams() > 0;
-    Type *GVType =
-        IsVec ? FixedVectorType::get(F.getReturnType(), 3) : F.getReturnType();
-    GlobalVariable *BV = nullptr;
-    // Consider the following LLVM IR:
-    // @__spirv_BuiltInLocalInvocationId = <Global constant>
-    // .....
-    // define spir_kernel void @kernel1(....) {
-    //   %3 = tail call i64 @_Z12get_local_idj(i32 0)
-    //   .....
-    //   return void
-    // }
-    // During the OCLToSPIRV pass, the opencl call will get lowered to
-    // yet another global variable with the name
-    // '@__spirv_BuiltInLocalInvocationId'. In such a case, we would want to
-    // create only a single global variable with this name.
-    if (GlobalVariable *GV = M->getGlobalVariable(BuiltinVarName))
-      BV = GV;
-    else
-      BV = new GlobalVariable(*M, GVType, /*isConstant=*/true,
-                              GlobalValue::ExternalLinkage, nullptr,
-                              BuiltinVarName, 0, GlobalVariable::NotThreadLocal,
-                              SPIRAS_Input);
-    for (auto *U : F.users()) {
-      auto *CI = dyn_cast<CallInst>(U);
-      assert(CI && "invalid instruction");
-      IRBuilder<> Builder(CI);
-      Value *NewValue = Builder.CreateLoad(GVType, BV);
-      LLVM_DEBUG(dbgs() << "Transform: " << *CI << " => " << *NewValue << '\n');
-      if (IsVec) {
-        auto *GVVecTy = cast<FixedVectorType>(GVType);
-        ConstantInt *Bound = Builder.getInt32(GVVecTy->getNumElements());
-        // Create a select on the index first, to avoid undefined behaviour
-        // due to exceeding the vector size by the extractelement.
-        Value *IndexCmp = Builder.CreateICmpULT(CI->getArgOperand(0), Bound);
-        Constant *ZeroIndex =
-            ConstantInt::get(CI->getArgOperand(0)->getType(), 0);
-        Value *ExtractIndex =
-            Builder.CreateSelect(IndexCmp, CI->getArgOperand(0), ZeroIndex);
-
-        // Extract from builtin variable.
-        NewValue = Builder.CreateExtractElement(NewValue, ExtractIndex);
-
-        // Clamp to out-of-range value.
-        Constant *OutOfRangeVal = ConstantInt::get(
-            F.getReturnType(), getBuiltinOutOfRangeValue(BuiltinVarName));
-        NewValue = Builder.CreateSelect(IndexCmp, NewValue, OutOfRangeVal);
-        LLVM_DEBUG(dbgs() << *NewValue << '\n');
-      }
-      NewValue->takeName(CI);
-      CI->replaceAllUsesWith(NewValue);
-      ToRemove.push_back(CI);
-    }
-    ToRemove.push_back(&F);
-  }
-  for (auto *V : ToRemove) {
-    if (auto *I = dyn_cast<Instruction>(V))
-      I->eraseFromParent();
-    else if (auto *F = dyn_cast<Function>(V))
-      F->eraseFromParent();
-    else
-      llvm_unreachable("Unexpected value to remove!");
-  }
-  return true;
-}
-
-bool lowerBuiltins(SPIRVModule *BM, Module *M) {
-  auto Format = BM->getBuiltinFormat();
-  if (Format == BuiltinFormat::Function && !lowerBuiltinVariablesToCalls(M))
-    return false;
-  if (Format == BuiltinFormat::Global && !lowerBuiltinCallsToVariables(M))
-    return false;
-  return true;
-}
-
 bool postProcessBuiltinReturningStruct(Function *F) {
   Module *M = F->getParent();
   LLVMContext *Context = &M->getContext();
@@ -2321,24 +2076,11 @@ bool postProcessBuiltinReturningStruct(Function *F) {
   SmallVector<Instruction *, 32> InstToRemove;
   for (auto *U : F->users()) {
     if (auto *CI = dyn_cast<CallInst>(U)) {
-      IRBuilder<> Builder(CI->getParent());
-      Builder.SetInsertPoint(CI);
-      SmallVector<User *> Users(CI->users());
-      Value *A = nullptr;
-      StoreInst *SI = nullptr;
-      for (auto *U : Users) {
-        if ((SI = dyn_cast<StoreInst>(U)) != nullptr) {
-          A = SI->getPointerOperand();
-          InstToRemove.push_back(SI);
-          break;
-        }
-      }
-      if (!A) {
-        A = Builder.CreateAlloca(F->getReturnType());
-      }
-      SmallVector<Type *> ArgTys;
+      auto *ST = cast<StoreInst>(*(CI->user_begin()));
+      std::vector<Type *> ArgTys;
       getFunctionTypeParameterTypes(F->getFunctionType(), ArgTys);
-      ArgTys.insert(ArgTys.begin(), A->getType());
+      ArgTys.insert(ArgTys.begin(),
+                    PointerType::get(F->getReturnType(), SPIRAS_Private));
       auto *NewF =
           getOrCreateFunction(M, Type::getVoidTy(*Context), ArgTys, Name);
       auto SretAttr = Attribute::get(*Context, Attribute::AttrKind::StructRet,
@@ -2346,20 +2088,11 @@ bool postProcessBuiltinReturningStruct(Function *F) {
       NewF->addParamAttr(0, SretAttr);
       NewF->setCallingConv(F->getCallingConv());
       auto Args = getArguments(CI);
-      Args.insert(Args.begin(), A);
-      CallInst *NewCI = Builder.CreateCall(
-          NewF, Args, NewF->getReturnType()->isVoidTy() ? "" : CI->getName());
+      Args.insert(Args.begin(), ST->getPointerOperand());
+      auto *NewCI = CallInst::Create(NewF, Args, CI->getName(), CI);
       NewCI->addParamAttr(0, SretAttr);
       NewCI->setCallingConv(CI->getCallingConv());
-      SmallVector<User *, 32> UsersToReplace;
-      for (auto *U : Users)
-        if (U != SI)
-          UsersToReplace.push_back(U);
-      if (UsersToReplace.size() > 0) {
-        auto *LI = Builder.CreateLoad(F->getReturnType(), A);
-        for (auto *U : UsersToReplace)
-          U->replaceUsesOfWith(CI, LI);
-      }
+      InstToRemove.push_back(ST);
       InstToRemove.push_back(CI);
     }
   }
@@ -2436,13 +2169,12 @@ bool postProcessBuiltinsWithArrayArguments(Module *M, bool IsCpp) {
 namespace {
 class SPIRVFriendlyIRMangleInfo : public BuiltinFuncMangleInfo {
 public:
-  SPIRVFriendlyIRMangleInfo(spv::Op OC, ArrayRef<Type *> ArgTys,
-                            ArrayRef<SPIRVValue *> Ops)
-      : OC(OC), ArgTys(ArgTys), Ops(Ops) {}
+  SPIRVFriendlyIRMangleInfo(spv::Op OC, ArrayRef<Type *> ArgTys)
+      : OC(OC), ArgTys(ArgTys) {}
 
   void init(StringRef UniqUnmangledName) override {
     UnmangledName = UniqUnmangledName.str();
-    switch (static_cast<unsigned>(OC)) {
+    switch (OC) {
     case OpConvertUToF:
     case OpUConvert:
     case OpSatConvertUToS:
@@ -2590,28 +2322,6 @@ public:
     case OpSubgroupAvcSicConfigureSkcINTEL:
       addUnsignedArgs(0, 4);
       break;
-    case OpUDotKHR:
-    case OpUDotAccSatKHR:
-      addUnsignedArg(-1);
-      break;
-    case OpSUDotKHR:
-    case OpSUDotAccSatKHR:
-      addUnsignedArg(1);
-      break;
-    case OpImageWrite: {
-      size_t Idx = getImageOperandsIndex(OC);
-      if (Ops.size() > Idx) {
-        auto ImOp = static_cast<SPIRVConstant *>(Ops[Idx])->getZExtIntValue();
-        if (ImOp & ImageOperandsMask::ImageOperandsZeroExtendMask)
-          addUnsignedArg(2);
-      }
-      break;
-    }
-    case internal::OpConvertHandleToImageINTEL:
-    case internal::OpConvertHandleToSamplerINTEL:
-    case internal::OpConvertHandleToSampledImageINTEL:
-      addUnsignedArg(0);
-      break;
     default:;
       // No special handling is needed
     }
@@ -2620,7 +2330,6 @@ public:
 private:
   spv::Op OC;
   ArrayRef<Type *> ArgTys;
-  ArrayRef<SPIRVValue *> Ops;
 };
 class OpenCLStdToSPIRVFriendlyIRMangleInfo : public BuiltinFuncMangleInfo {
 public:
@@ -2690,9 +2399,9 @@ std::string getSPIRVFriendlyIRFunctionName(OCLExtOpKind ExtOpId,
 }
 
 std::string getSPIRVFriendlyIRFunctionName(const std::string &UniqName,
-                                           spv::Op OC, ArrayRef<Type *> ArgTys,
-                                           ArrayRef<SPIRVValue *> Ops) {
-  SPIRVFriendlyIRMangleInfo MangleInfo(OC, ArgTys, Ops);
+                                           spv::Op OC,
+                                           ArrayRef<Type *> ArgTys) {
+  SPIRVFriendlyIRMangleInfo MangleInfo(OC, ArgTys);
   return mangleBuiltin(UniqName, ArgTys, &MangleInfo);
 }
 
