@@ -78,10 +78,6 @@ public:
       BuiltIn BI = static_cast<BuiltIn>(Literals.back());
       return getCapability(BI);
     }
-    case DecorationUniform:
-      if (Module->isAllowedToUseVersion(VersionNumber::SPIRV_1_6))
-        return getVec(CapabilityUniformDecoration);
-      return getVec(CapabilityShader);
 
     default:
       return getCapability(Dec);
@@ -99,7 +95,6 @@ public:
     case DecorationMaxByteOffset:
       return static_cast<SPIRVWord>(VersionNumber::SPIRV_1_1);
     case DecorationUserSemantic:
-    case DecorationCounterBuffer:
       return static_cast<SPIRVWord>(VersionNumber::SPIRV_1_4);
 
     default:
@@ -167,6 +162,8 @@ public:
       return ExtensionID::SPV_INTEL_fpga_cluster_attributes;
     case DecorationFuseLoopsInFunctionINTEL:
       return ExtensionID::SPV_INTEL_loop_fuse;
+    case internal::DecorationCallableFunctionINTEL:
+      return ExtensionID::SPV_INTEL_fast_composite;
     case DecorationMathOpDSPModeINTEL:
       return ExtensionID::SPV_INTEL_fpga_dsp_control;
     case DecorationInitiationIntervalINTEL:
@@ -181,12 +178,6 @@ public:
     case internal::DecorationInitModeINTEL:
     case internal::DecorationImplementInCSRINTEL:
       return ExtensionID::SPV_INTEL_global_variable_decorations;
-    case DecorationInitModeINTEL:
-    case DecorationImplementInRegisterMapINTEL:
-      return ExtensionID::SPV_INTEL_global_variable_fpga_decorations;
-    case DecorationHostAccessINTEL:
-      return ExtensionID::SPV_INTEL_global_variable_host_access;
-
     case DecorationConduitKernelArgumentINTEL:
     case DecorationRegisterMapKernelArgumentINTEL:
     case DecorationStableKernelArgumentINTEL:
@@ -197,11 +188,6 @@ public:
     case DecorationMMHostInterfaceMaxBurstINTEL:
     case DecorationMMHostInterfaceWaitRequestINTEL:
       return ExtensionID::SPV_INTEL_fpga_argument_interfaces;
-    case DecorationFPMaxErrorDecorationINTEL:
-      return ExtensionID::SPV_INTEL_fp_max_error;
-    case DecorationCacheControlLoadINTEL:
-    case DecorationCacheControlStoreINTEL:
-      return ExtensionID::SPV_INTEL_cache_controls;
     default:
       return {};
     }
@@ -215,8 +201,6 @@ public:
   }
 };
 
-class SPIRVDecorateString : public SPIRVDecorate {};
-
 class SPIRVDecorateId : public SPIRVDecorateGeneric {
 public:
   static const Op OC = OpDecorateId;
@@ -366,8 +350,6 @@ protected:
   SPIRVWord MemberNumber;
 };
 
-class SPIRVMemberDecorateString : public SPIRVMemberDecorate {};
-
 class SPIRVDecorationGroup : public SPIRVEntry {
 public:
   static const Op OC = OpDecorationGroup;
@@ -727,13 +709,12 @@ public:
       : SPIRVDecorate(spv::DecorationPipelineEnableINTEL, TheTarget, Enable){};
 };
 
-class SPIRVDecorateHostAccessINTELBase : public SPIRVDecorate {
+class SPIRVDecorateHostAccessINTEL : public SPIRVDecorate {
 public:
   // Complete constructor for SPIRVHostAccessINTEL
-  SPIRVDecorateHostAccessINTELBase(Decoration D, SPIRVEntry *TheTarget,
-                                   HostAccessQualifier AccessMode,
-                                   const std::string &VarName)
-      : SPIRVDecorate(D, TheTarget) {
+  SPIRVDecorateHostAccessINTEL(SPIRVEntry *TheTarget, SPIRVWord AccessMode,
+                               const std::string &VarName)
+      : SPIRVDecorate(spv::internal::DecorationHostAccessINTEL, TheTarget) {
     Literals.push_back(AccessMode);
     for (auto &I : getVec(VarName))
       Literals.push_back(I);
@@ -744,53 +725,7 @@ public:
   std::string getVarName() const {
     return getString(Literals.cbegin() + 1, Literals.cend());
   }
-};
 
-class SPIRVDecorateHostAccessINTEL : public SPIRVDecorateHostAccessINTELBase {
-public:
-  SPIRVDecorateHostAccessINTEL(SPIRVEntry *TheTarget,
-                               HostAccessQualifier AccessMode,
-                               const std::string &VarName)
-      : SPIRVDecorateHostAccessINTELBase(DecorationHostAccessINTEL, TheTarget,
-                                         AccessMode, VarName) {}
-  static void encodeLiterals(SPIRVEncoder &Encoder,
-                             const std::vector<SPIRVWord> &Literals) {
-#ifdef _SPIRV_SUPPORT_TEXT_FMT
-    if (SPIRVUseTextFormat) {
-      Encoder << (HostAccessQualifier)Literals.front();
-      std::string Name = getString(Literals.cbegin() + 1, Literals.cend());
-      Encoder << Name;
-    } else
-#endif
-      Encoder << Literals;
-  }
-
-  static void decodeLiterals(SPIRVDecoder &Decoder,
-                             std::vector<SPIRVWord> &Literals) {
-#ifdef _SPIRV_SUPPORT_TEXT_FMT
-    if (SPIRVUseTextFormat) {
-      HostAccessQualifier Mode;
-      Decoder >> Mode;
-      std::string Name;
-      Decoder >> Name;
-      Literals.front() = Mode;
-      std::copy_n(getVec(Name).begin(), Literals.size() - 1,
-                  Literals.begin() + 1);
-
-    } else
-#endif
-      Decoder >> Literals;
-  }
-};
-
-class SPIRVDecorateHostAccessINTELLegacy
-    : public SPIRVDecorateHostAccessINTELBase {
-public:
-  SPIRVDecorateHostAccessINTELLegacy(SPIRVEntry *TheTarget,
-                                     HostAccessQualifier AccessMode,
-                                     const std::string &VarName)
-      : SPIRVDecorateHostAccessINTELBase(internal::DecorationHostAccessINTEL,
-                                         TheTarget, AccessMode, VarName) {}
   static void encodeLiterals(SPIRVEncoder &Encoder,
                              const std::vector<SPIRVWord> &Literals) {
 #ifdef _SPIRV_SUPPORT_TEXT_FMT
@@ -821,75 +756,12 @@ public:
   }
 };
 
-class SPIRVDecorateInitModeINTELBase : public SPIRVDecorate {
+class SPIRVDecorateInitModeINTEL : public SPIRVDecorate {
 public:
   // Complete constructor for SPIRVInitModeINTEL
-  SPIRVDecorateInitModeINTELBase(Decoration D, SPIRVEntry *TheTarget,
-                                 InitializationModeQualifier Trigger)
-      : SPIRVDecorate(D, TheTarget) {
-    Literals.push_back(Trigger);
-    WordCount += Literals.size();
-  }
-};
-
-class SPIRVDecorateInitModeINTEL : public SPIRVDecorateInitModeINTELBase {
-public:
-  SPIRVDecorateInitModeINTEL(SPIRVEntry *TheTarget,
-                             InitializationModeQualifier Trigger)
-      : SPIRVDecorateInitModeINTELBase(DecorationInitModeINTEL, TheTarget,
-                                       Trigger) {}
-
-  static void encodeLiterals(SPIRVEncoder &Encoder,
-                             const std::vector<SPIRVWord> &Literals) {
-#ifdef _SPIRV_SUPPORT_TEXT_FMT
-    if (SPIRVUseTextFormat) {
-      Encoder << (InitializationModeQualifier)Literals.back();
-    } else
-#endif
-      Encoder << Literals;
-  }
-
-  static void decodeLiterals(SPIRVDecoder &Decoder,
-                             std::vector<SPIRVWord> &Literals) {
-#ifdef _SPIRV_SUPPORT_TEXT_FMT
-    if (SPIRVUseTextFormat) {
-      InitializationModeQualifier Q;
-      Decoder >> Q;
-      Literals.back() = Q;
-    } else
-#endif
-      Decoder >> Literals;
-  }
-};
-
-class SPIRVDecorateInitModeINTELLegacy : public SPIRVDecorateInitModeINTELBase {
-public:
-  SPIRVDecorateInitModeINTELLegacy(SPIRVEntry *TheTarget,
-                                   InitializationModeQualifier Trigger)
-      : SPIRVDecorateInitModeINTELBase(internal::DecorationInitModeINTEL,
-                                       TheTarget, Trigger) {}
-
-  static void encodeLiterals(SPIRVEncoder &Encoder,
-                             const std::vector<SPIRVWord> &Literals) {
-#ifdef _SPIRV_SUPPORT_TEXT_FMT
-    if (SPIRVUseTextFormat) {
-      Encoder << Literals.back();
-    } else
-#endif
-      Encoder << Literals;
-  }
-
-  static void decodeLiterals(SPIRVDecoder &Decoder,
-                             std::vector<SPIRVWord> &Literals) {
-#ifdef _SPIRV_SUPPORT_TEXT_FMT
-    if (SPIRVUseTextFormat) {
-      SPIRVWord Q;
-      Decoder >> Q;
-      Literals.back() = Q;
-    } else
-#endif
-      Decoder >> Literals;
-  }
+  SPIRVDecorateInitModeINTEL(SPIRVEntry *TheTarget, SPIRVWord Trigger)
+      : SPIRVDecorate(spv::internal::DecorationInitModeINTEL, TheTarget,
+                      Trigger){};
 };
 
 class SPIRVDecorateImplementInCSRINTEL : public SPIRVDecorate {
@@ -897,46 +769,7 @@ public:
   // Complete constructor for SPIRVImplementInCSRINTEL
   SPIRVDecorateImplementInCSRINTEL(SPIRVEntry *TheTarget, SPIRVWord Value)
       : SPIRVDecorate(spv::internal::DecorationImplementInCSRINTEL, TheTarget,
-                      Value) {}
-};
-
-class SPIRVDecorateImplementInRegisterMapINTEL : public SPIRVDecorate {
-public:
-  // Complete constructor for SPIRVImplementInCSRINTEL
-  SPIRVDecorateImplementInRegisterMapINTEL(SPIRVEntry *TheTarget,
-                                           SPIRVWord Value)
-      : SPIRVDecorate(DecorationImplementInRegisterMapINTEL, TheTarget, Value) {
-  }
-};
-
-class SPIRVDecorateCacheControlLoadINTEL : public SPIRVDecorate {
-public:
-  // Complete constructor for SPIRVDecorateCacheControlLoadINTEL
-  SPIRVDecorateCacheControlLoadINTEL(SPIRVEntry *TheTarget,
-                                     SPIRVWord CacheLevel,
-                                     LoadCacheControl CacheControl)
-      : SPIRVDecorate(DecorationCacheControlLoadINTEL, TheTarget, CacheLevel,
-                      static_cast<SPIRVWord>(CacheControl)) {}
-
-  SPIRVWord getCacheLevel() const { return Literals.at(0); }
-  LoadCacheControl getCacheControl() const {
-    return static_cast<LoadCacheControl>(Literals.at(1));
-  }
-};
-
-class SPIRVDecorateCacheControlStoreINTEL : public SPIRVDecorate {
-public:
-  // Complete constructor for SPIRVDecorateCacheControlStoreINTEL
-  SPIRVDecorateCacheControlStoreINTEL(SPIRVEntry *TheTarget,
-                                      SPIRVWord CacheLevel,
-                                      StoreCacheControl CacheControl)
-      : SPIRVDecorate(DecorationCacheControlStoreINTEL, TheTarget, CacheLevel,
-                      static_cast<SPIRVWord>(CacheControl)) {}
-
-  SPIRVWord getCacheLevel() const { return Literals.at(0); }
-  StoreCacheControl getCacheControl() const {
-    return static_cast<StoreCacheControl>(Literals.at(1));
-  }
+                      Value){};
 };
 
 } // namespace SPIRV
