@@ -288,7 +288,6 @@ public:
     return Id;
   }
   std::shared_ptr<const SPIRVLine> getLine() const { return Line; }
-  std::shared_ptr<const SPIRVExtInst> getDebugLine() const { return DebugLine; }
   SPIRVLinkageTypeKind getLinkageType() const;
   Op getOpCode() const { return OpCode; }
   SPIRVModule *getModule() const { return Module; }
@@ -361,7 +360,6 @@ public:
   void setHasNoId() { Attrib |= SPIRVEA_NOID; }
   void setId(SPIRVId TheId) { Id = TheId; }
   void setLine(const std::shared_ptr<const SPIRVLine> &L);
-  void setDebugLine(const std::shared_ptr<const SPIRVExtInst> &DL);
   void setLinkageType(SPIRVLinkageTypeKind);
   void setModule(SPIRVModule *TheModule);
   void setName(const std::string &TheName);
@@ -370,7 +368,6 @@ public:
   void takeDecorates(SPIRVEntry *);
   void takeDecorateIds(SPIRVEntry *);
   void takeMemberDecorates(SPIRVEntry *);
-  void replaceTargetIdInDecorates(SPIRVId);
 
   /// After a SPIRV entry is created during reading SPIRV binary by default
   /// constructor, this function is called to allow the SPIRV entry to resize
@@ -389,7 +386,6 @@ public:
   friend spv_ostream &operator<<(spv_ostream &O, const SPIRVEntry &E);
   friend std::istream &operator>>(std::istream &I, SPIRVEntry &E);
   virtual void encodeLine(spv_ostream &O) const;
-  virtual void encodeDebugLine(spv_ostream &O) const;
   virtual void encodeAll(spv_ostream &O) const;
   virtual void encodeName(spv_ostream &O) const;
   virtual void encodeChildren(spv_ostream &O) const;
@@ -454,7 +450,6 @@ protected:
   DecorateIdMapType DecorateIds;
   MemberDecorateMapType MemberDecorates;
   std::shared_ptr<const SPIRVLine> Line;
-  std::shared_ptr<const SPIRVExtInst> DebugLine;
 };
 
 class SPIRVEntryNoIdGeneric : public SPIRVEntry {
@@ -521,24 +516,23 @@ protected:
   SPIRVId Target;
 };
 
-class SPIRVAnnotation : public SPIRVAnnotationGeneric {
+template <Op OC> class SPIRVAnnotation : public SPIRVAnnotationGeneric {
 public:
   // Complete constructor
-  SPIRVAnnotation(Op OC, const SPIRVEntry *TheTarget, unsigned TheWordCount)
+  SPIRVAnnotation(const SPIRVEntry *TheTarget, unsigned TheWordCount)
       : SPIRVAnnotationGeneric(TheTarget->getModule(), TheWordCount, OC,
                                TheTarget->getId()) {}
-  // Incomplete constructors
-  SPIRVAnnotation(Op OC) : SPIRVAnnotationGeneric(OC) {}
-  SPIRVAnnotation() : SPIRVAnnotationGeneric(OpNop) {}
+  // Incomplete constructor
+  SPIRVAnnotation() : SPIRVAnnotationGeneric(OC) {}
 };
 
-class SPIRVEntryPoint : public SPIRVAnnotation {
+class SPIRVEntryPoint : public SPIRVAnnotation<OpEntryPoint> {
 public:
   static const SPIRVWord FixedWC = 4;
   SPIRVEntryPoint(SPIRVModule *TheModule, SPIRVExecutionModelKind,
                   SPIRVId TheId, const std::string &TheName,
                   std::vector<SPIRVId> Variables);
-  SPIRVEntryPoint() : SPIRVAnnotation(OpEntryPoint) {}
+  SPIRVEntryPoint() {}
 
   _SPIRV_DCL_ENCDEC
 protected:
@@ -549,12 +543,12 @@ private:
   std::vector<SPIRVId> Variables;
 };
 
-class SPIRVName : public SPIRVAnnotation {
+class SPIRVName : public SPIRVAnnotation<OpName> {
 public:
   // Complete constructor
   SPIRVName(const SPIRVEntry *TheTarget, const std::string &TheStr);
   // Incomplete constructor
-  SPIRVName() : SPIRVAnnotation(OpName) {}
+  SPIRVName() {}
 
 protected:
   _SPIRV_DCL_ENCDEC
@@ -563,18 +557,18 @@ protected:
   std::string Str;
 };
 
-class SPIRVMemberName : public SPIRVAnnotation {
+class SPIRVMemberName : public SPIRVAnnotation<OpName> {
 public:
   static const SPIRVWord FixedWC = 3;
   // Complete constructor
   SPIRVMemberName(const SPIRVEntry *TheTarget, SPIRVWord TheMemberNumber,
                   const std::string &TheStr)
-      : SPIRVAnnotation(OpName, TheTarget, FixedWC + getSizeInWords(TheStr)),
+      : SPIRVAnnotation(TheTarget, FixedWC + getSizeInWords(TheStr)),
         MemberNumber(TheMemberNumber), Str(TheStr) {
     validate();
   }
   // Incomplete constructor
-  SPIRVMemberName() : SPIRVAnnotation(OpName), MemberNumber(SPIRVWORD_MAX) {}
+  SPIRVMemberName() : MemberNumber(SPIRVWORD_MAX) {}
 
 protected:
   _SPIRV_DCL_ENCDEC
@@ -650,33 +644,31 @@ protected:
   SPIRVWord Column;
 };
 
-class SPIRVExecutionMode : public SPIRVAnnotation {
+class SPIRVExecutionMode : public SPIRVAnnotation<OpExecutionMode> {
 public:
   // Complete constructor for LocalSize, LocalSizeHint
-  SPIRVExecutionMode(Op OC, SPIRVEntry *TheTarget,
-                     SPIRVExecutionModeKind TheExecMode, SPIRVWord X,
-                     SPIRVWord Y, SPIRVWord Z)
-      : SPIRVAnnotation(OC, TheTarget, 6), ExecMode(TheExecMode) {
+  SPIRVExecutionMode(SPIRVEntry *TheTarget, SPIRVExecutionModeKind TheExecMode,
+                     SPIRVWord X, SPIRVWord Y, SPIRVWord Z)
+      : SPIRVAnnotation(TheTarget, 6), ExecMode(TheExecMode) {
     WordLiterals.push_back(X);
     WordLiterals.push_back(Y);
     WordLiterals.push_back(Z);
     updateModuleVersion();
   }
   // Complete constructor for VecTypeHint, SubgroupSize, SubgroupsPerWorkgroup
-  SPIRVExecutionMode(Op OC, SPIRVEntry *TheTarget,
-                     SPIRVExecutionModeKind TheExecMode, SPIRVWord Code)
-      : SPIRVAnnotation(OC, TheTarget, 4), ExecMode(TheExecMode) {
+  SPIRVExecutionMode(SPIRVEntry *TheTarget, SPIRVExecutionModeKind TheExecMode,
+                     SPIRVWord Code)
+      : SPIRVAnnotation(TheTarget, 4), ExecMode(TheExecMode) {
     WordLiterals.push_back(Code);
+    updateModuleVersion();
   }
   // Complete constructor for ContractionOff
-  SPIRVExecutionMode(Op OC, SPIRVEntry *TheTarget,
-                     SPIRVExecutionModeKind TheExecMode)
-      : SPIRVAnnotation(OC, TheTarget, 3), ExecMode(TheExecMode) {
+  SPIRVExecutionMode(SPIRVEntry *TheTarget, SPIRVExecutionModeKind TheExecMode)
+      : SPIRVAnnotation(TheTarget, 3), ExecMode(TheExecMode) {
     updateModuleVersion();
   }
   // Incomplete constructor
-  SPIRVExecutionMode()
-      : SPIRVAnnotation(OpExecutionMode), ExecMode(ExecutionModeInvocations) {}
+  SPIRVExecutionMode() : ExecMode(ExecutionModeInvocations) {}
   SPIRVExecutionModeKind getExecutionMode() const { return ExecMode; }
   const std::vector<SPIRVWord> &getLiterals() const { return WordLiterals; }
   SPIRVCapVec getRequiredCapability() const override {
@@ -696,45 +688,12 @@ public:
     }
   }
 
-  std::optional<ExtensionID> getRequiredExtension() const override {
-    switch (static_cast<unsigned>(ExecMode)) {
-    case ExecutionModeMaximumRegistersINTEL:
-    case ExecutionModeMaximumRegistersIdINTEL:
-    case ExecutionModeNamedMaximumRegistersINTEL:
-      return ExtensionID::SPV_INTEL_maximum_registers;
-    default:
-      return {};
-    }
-  }
-
 protected:
   _SPIRV_DCL_ENCDEC
   SPIRVExecutionModeKind ExecMode;
   std::vector<SPIRVWord> WordLiterals;
 };
 
-class SPIRVExecutionModeId : public SPIRVExecutionMode {
-public:
-  // Complete constructor for LocalSizeId, LocalSizeHintId
-  SPIRVExecutionModeId(SPIRVEntry *TheTarget,
-                       SPIRVExecutionModeKind TheExecMode, SPIRVWord X,
-                       SPIRVWord Y, SPIRVWord Z)
-      : SPIRVExecutionMode(OpExecutionModeId, TheTarget, TheExecMode, X, Y, Z) {
-    updateModuleVersion();
-  }
-  // Complete constructor for SubgroupsPerWorkgroupId
-  SPIRVExecutionModeId(SPIRVEntry *TheTarget,
-                       SPIRVExecutionModeKind TheExecMode, SPIRVWord Code)
-      : SPIRVExecutionMode(OpExecutionModeId, TheTarget, TheExecMode, Code) {
-    updateModuleVersion();
-  }
-  // Incomplete constructor
-  SPIRVExecutionModeId() : SPIRVExecutionMode() {}
-  SPIRVWord getRequiredSPIRVVersion() const override {
-    return static_cast<SPIRVWord>(VersionNumber::SPIRV_1_2);
-  }
-};
-
 class SPIRVComponentExecutionModes {
   typedef std::multimap<SPIRVExecutionModeKind, SPIRVExecutionMode *>
       SPIRVExecutionModeMap;
@@ -768,11 +727,6 @@ public:
       return IsDenorm(EMK) || IsRoundingMode(EMK) || IsFPMode(EMK) ||
              IsOtherFP(EMK);
     };
-    auto IsMaxRegisters = [&](auto EMK) {
-      return EMK == ExecutionModeMaximumRegistersINTEL ||
-             EMK == ExecutionModeMaximumRegistersIdINTEL ||
-             EMK == ExecutionModeNamedMaximumRegistersINTEL;
-    };
     auto IsCompatible = [&](SPIRVExecutionMode *EM0, SPIRVExecutionMode *EM1) {
       if (EM0->getTargetId() != EM1->getTargetId())
         return true;
@@ -786,8 +740,7 @@ public:
         return true;
       return !(IsDenorm(EMK0) && IsDenorm(EMK1)) &&
              !(IsRoundingMode(EMK0) && IsRoundingMode(EMK1)) &&
-             !(IsFPMode(EMK0) && IsFPMode(EMK1)) &&
-             !(IsMaxRegisters(EMK0) && IsMaxRegisters(EMK1));
+             !(IsFPMode(EMK0) && IsFPMode(EMK1));
     };
     for (auto I = ExecModes.begin(); I != ExecModes.end(); ++I) {
       assert(IsCompatible(ExecMode, (*I).second) &&
@@ -803,12 +756,6 @@ public:
       return nullptr;
     return Loc->second;
   }
-  SPIRVExecutionModeId *getExecutionModeId(SPIRVExecutionModeKind EMK) const {
-    auto Loc = ExecModes.find(EMK);
-    if (Loc == ExecModes.end())
-      return nullptr;
-    return static_cast<SPIRVExecutionModeId *>(Loc->second);
-  }
   SPIRVExecutionModeRange
   getExecutionModeRange(SPIRVExecutionModeKind EMK) const {
     return ExecModes.equal_range(EMK);
@@ -906,11 +853,8 @@ public:
     case CapabilityVectorComputeINTEL:
     case CapabilityVectorAnyINTEL:
       return ExtensionID::SPV_INTEL_vector_compute;
-    case CapabilityFunctionVariantsINTEL:
-    case CapabilitySpecConditionalINTEL:
-      return ExtensionID::SPV_INTEL_function_variants;
-    case internal::CapabilityBFloat16ArithmeticINTEL:
-      return ExtensionID::SPV_INTEL_bfloat16_arithmetic;
+    case internal::CapabilityFastCompositeINTEL:
+      return ExtensionID::SPV_INTEL_fast_composite;
     default:
       return {};
     }
@@ -959,7 +903,7 @@ public:
   }
 
   SPIRVCapVec getRequiredCapability() const override {
-    return getVec(CapabilityLongCompositesINTEL);
+    return getVec(CapabilityLongConstantCompositeINTEL);
   }
 
   std::optional<ExtensionID> getRequiredExtension() const override {
@@ -1060,6 +1004,10 @@ _SPIRV_OP(ImageDrefGather)
 _SPIRV_OP(QuantizeToF16)
 _SPIRV_OP(ArrayLength)
 _SPIRV_OP(OuterProduct)
+_SPIRV_OP(IAddCarry)
+_SPIRV_OP(ISubBorrow)
+_SPIRV_OP(SMulExtended)
+_SPIRV_OP(UMulExtended)
 _SPIRV_OP(DPdx)
 _SPIRV_OP(DPdy)
 _SPIRV_OP(Fwidth)
@@ -1092,6 +1040,7 @@ _SPIRV_OP(NamedBarrierInitialize)
 _SPIRV_OP(MemoryNamedBarrier)
 _SPIRV_OP(GetKernelMaxNumSubgroups)
 _SPIRV_OP(GetKernelLocalSizeForSubgroupCount)
+_SPIRV_OP(SizeOf)
 #undef _SPIRV_OP
 
 } // namespace SPIRV
