@@ -78,9 +78,6 @@ enum SPIRVExtInstSetKind {
   SPIRVEIS_OpenCL,
   SPIRVEIS_Debug,
   SPIRVEIS_OpenCL_DebugInfo_100,
-  SPIRVEIS_NonSemantic_Shader_DebugInfo_100,
-  SPIRVEIS_NonSemantic_Shader_DebugInfo_200,
-  SPIRVEIS_NonSemantic_AuxData,
   SPIRVEIS_Count,
 };
 
@@ -132,11 +129,6 @@ template <> inline void SPIRVMap<SPIRVExtInstSetKind, std::string>::init() {
   add(SPIRVEIS_OpenCL, "OpenCL.std");
   add(SPIRVEIS_Debug, "SPIRV.debug");
   add(SPIRVEIS_OpenCL_DebugInfo_100, "OpenCL.DebugInfo.100");
-  add(SPIRVEIS_NonSemantic_Shader_DebugInfo_100,
-      "NonSemantic.Shader.DebugInfo.100");
-  add(SPIRVEIS_NonSemantic_Shader_DebugInfo_200,
-      "NonSemantic.Shader.DebugInfo.200");
-  add(SPIRVEIS_NonSemantic_AuxData, "NonSemantic.AuxData");
 }
 typedef SPIRVMap<SPIRVExtInstSetKind, std::string> SPIRVBuiltinSetNameMap;
 
@@ -205,29 +197,6 @@ template <> inline void SPIRVMap<SPIRVCapabilityKind, SPIRVCapVec>::init() {
                {CapabilitySubgroupAvcMotionEstimationINTEL});
   ADD_VEC_INIT(CapabilitySubgroupAvcMotionEstimationChromaINTEL,
                {CapabilitySubgroupAvcMotionEstimationIntraINTEL});
-  ADD_VEC_INIT(internal::CapabilityJointMatrixWIInstructionsINTEL,
-               {internal::CapabilityJointMatrixINTEL});
-  ADD_VEC_INIT(internal::CapabilityCooperativeMatrixCheckedInstructionsINTEL,
-               {CapabilityCooperativeMatrixKHR});
-  ADD_VEC_INIT(internal::CapabilityCooperativeMatrixPrefetchINTEL,
-               {CapabilityCooperativeMatrixKHR});
-  ADD_VEC_INIT(CapabilityBFloat16DotProductKHR, {CapabilityBFloat16TypeKHR});
-  ADD_VEC_INIT(CapabilityBFloat16CooperativeMatrixKHR,
-               {CapabilityBFloat16TypeKHR, CapabilityCooperativeMatrixKHR});
-  ADD_VEC_INIT(CapabilityInt4CooperativeMatrixINTEL,
-               {CapabilityInt4TypeINTEL, CapabilityCooperativeMatrixKHR});
-  ADD_VEC_INIT(internal::CapabilityBFloat16ArithmeticINTEL,
-               {CapabilityBFloat16TypeKHR});
-  ADD_VEC_INIT(internal::CapabilityAtomicInt16CompareExchangeINTEL,
-               {CapabilityInt16});
-  ADD_VEC_INIT(internal::CapabilityInt16AtomicsINTEL,
-               {internal::CapabilityAtomicInt16CompareExchangeINTEL});
-  ADD_VEC_INIT(internal::CapabilityAtomicBFloat16LoadStoreINTEL,
-               {CapabilityBFloat16TypeKHR});
-  ADD_VEC_INIT(internal::CapabilityAtomicBFloat16AddINTEL,
-               {CapabilityBFloat16TypeKHR});
-  ADD_VEC_INIT(internal::CapabilityAtomicBFloat16MinMaxINTEL,
-               {CapabilityBFloat16TypeKHR});
 }
 
 template <> inline void SPIRVMap<SPIRVExecutionModelKind, SPIRVCapVec>::init() {
@@ -290,16 +259,12 @@ template <> inline void SPIRVMap<SPIRVExecutionModeKind, SPIRVCapVec>::init() {
                {CapabilityFloatingPointModeINTEL});
   ADD_VEC_INIT(ExecutionModeSharedLocalMemorySizeINTEL,
                {CapabilityVectorComputeINTEL});
+  ADD_VEC_INIT(internal::ExecutionModeFastCompositeKernelINTEL,
+               {internal::CapabilityFastCompositeINTEL});
   ADD_VEC_INIT(ExecutionModeStreamingInterfaceINTEL,
                {CapabilityFPGAKernelAttributesINTEL});
   ADD_VEC_INIT(ExecutionModeNamedBarrierCountINTEL,
                {CapabilityVectorComputeINTEL});
-  ADD_VEC_INIT(ExecutionModeMaximumRegistersINTEL,
-               {CapabilityRegisterLimitsINTEL});
-  ADD_VEC_INIT(ExecutionModeMaximumRegistersIdINTEL,
-               {CapabilityRegisterLimitsINTEL});
-  ADD_VEC_INIT(ExecutionModeNamedMaximumRegistersINTEL,
-               {CapabilityRegisterLimitsINTEL});
 }
 
 template <> inline void SPIRVMap<SPIRVMemoryModelKind, SPIRVCapVec>::init() {
@@ -395,6 +360,7 @@ template <> inline void SPIRVMap<Decoration, SPIRVCapVec>::init() {
   ADD_VEC_INIT(DecorationSample, {CapabilitySampleRateShading});
   ADD_VEC_INIT(DecorationInvariant, {CapabilityShader});
   ADD_VEC_INIT(DecorationConstant, {CapabilityKernel});
+  ADD_VEC_INIT(DecorationUniform, {CapabilityShader});
   ADD_VEC_INIT(DecorationSaturatedConversion, {CapabilityKernel});
   ADD_VEC_INIT(DecorationStream, {CapabilityGeometryStreams});
   ADD_VEC_INIT(DecorationLocation, {CapabilityShader});
@@ -462,6 +428,8 @@ template <> inline void SPIRVMap<Decoration, SPIRVCapVec>::init() {
   ADD_VEC_INIT(DecorationAliasScopeINTEL,
                {CapabilityMemoryAccessAliasingINTEL});
   ADD_VEC_INIT(DecorationNoAliasINTEL, {CapabilityMemoryAccessAliasingINTEL});
+  ADD_VEC_INIT(internal::DecorationCallableFunctionINTEL,
+               {internal::CapabilityFastCompositeINTEL});
   ADD_VEC_INIT(DecorationMediaBlockIOINTEL, {CapabilityVectorComputeINTEL});
   ADD_VEC_INIT(DecorationStallEnableINTEL,
                {CapabilityFPGAClusterAttributesINTEL});
@@ -481,17 +449,8 @@ template <> inline void SPIRVMap<Decoration, SPIRVCapVec>::init() {
                {internal::CapabilityGlobalVariableDecorationsINTEL});
   ADD_VEC_INIT(internal::DecorationImplementInCSRINTEL,
                {internal::CapabilityGlobalVariableDecorationsINTEL});
-  ADD_VEC_INIT(DecorationHostAccessINTEL,
-               {CapabilityGlobalVariableHostAccessINTEL});
-  ADD_VEC_INIT(DecorationInitModeINTEL,
-               {CapabilityGlobalVariableFPGADecorationsINTEL});
-  ADD_VEC_INIT(DecorationImplementInRegisterMapINTEL,
-               {CapabilityGlobalVariableFPGADecorationsINTEL});
   ADD_VEC_INIT(internal::DecorationArgumentAttributeINTEL,
                {CapabilityFunctionPointersINTEL});
-  ADD_VEC_INIT(DecorationCacheControlLoadINTEL, {CapabilityCacheControlsINTEL});
-  ADD_VEC_INIT(DecorationCacheControlStoreINTEL,
-               {CapabilityCacheControlsINTEL});
   ADD_VEC_INIT(DecorationConduitKernelArgumentINTEL,
                {CapabilityFPGAArgumentInterfacesINTEL});
   ADD_VEC_INIT(DecorationRegisterMapKernelArgumentINTEL,
@@ -510,8 +469,6 @@ template <> inline void SPIRVMap<Decoration, SPIRVCapVec>::init() {
                {CapabilityFPGAArgumentInterfacesINTEL});
   ADD_VEC_INIT(DecorationStableKernelArgumentINTEL,
                {CapabilityFPGAArgumentInterfacesINTEL});
-  ADD_VEC_INIT(DecorationFPMaxErrorDecorationINTEL,
-               {CapabilityFPMaxErrorINTEL});
 }
 
 template <> inline void SPIRVMap<BuiltIn, SPIRVCapVec>::init() {
