@@ -58,44 +58,6 @@
 
 namespace SPIRV {
 
-namespace {
-std::string to_string(uint32_t Version) {
-  std::string Res;
-  switch (Version) {
-  case static_cast<uint32_t>(VersionNumber::SPIRV_1_0):
-    Res = "1.0";
-    break;
-  case static_cast<uint32_t>(VersionNumber::SPIRV_1_1):
-    Res = "1.1";
-    break;
-  case static_cast<uint32_t>(VersionNumber::SPIRV_1_2):
-    Res = "1.2";
-    break;
-  case static_cast<uint32_t>(VersionNumber::SPIRV_1_3):
-    Res = "1.3";
-    break;
-  case static_cast<uint32_t>(VersionNumber::SPIRV_1_4):
-    Res = "1.4";
-    break;
-  case static_cast<uint32_t>(VersionNumber::SPIRV_1_5):
-    Res = "1.5";
-    break;
-  case static_cast<uint32_t>(VersionNumber::SPIRV_1_6):
-    Res = "1.6";
-    break;
-  default:
-    Res = "unknown";
-  }
-
-  Res += " (" + std::to_string(Version) + ")";
-  return Res;
-}
-
-std::string to_string(VersionNumber Version) {
-  return to_string(static_cast<uint32_t>(Version));
-}
-} // Anonymous namespace
-
 SPIRVModule::SPIRVModule()
     : AutoAddCapability(true), ValidateCapability(false), IsValid(true) {}
 
@@ -168,13 +130,6 @@ public:
   SPIRVConstant *getLiteralAsConstant(unsigned Literal) override;
   unsigned getNumFunctions() const override { return FuncVec.size(); }
   unsigned getNumVariables() const override { return VariableVec.size(); }
-  std::vector<SPIRVValue *> getFunctionPointers() const override {
-    std::vector<SPIRVValue *> Res;
-    for (auto *C : ConstVec)
-      if (C->getOpCode() == OpConstantFunctionPointerINTEL)
-        Res.emplace_back(C);
-    return Res;
-  }
   SourceLanguage getSourceLanguage(SPIRVWord *Ver = nullptr) const override {
     if (Ver)
       *Ver = SrcLangVer;
@@ -188,9 +143,6 @@ public:
   const std::vector<SPIRVExtInst *> &getDebugInstVec() const override {
     return DebugInstVec;
   }
-  const std::vector<SPIRVExtInst *> &getAuxDataInstVec() const override {
-    return AuxDataInstVec;
-  }
   const std::vector<SPIRVString *> &getStringVec() const override {
     return StringVec;
   }
@@ -217,16 +169,7 @@ public:
   void insertEntryNoId(SPIRVEntry *Entry) override { EntryNoId.insert(Entry); }
 
   void setSPIRVVersion(SPIRVWord Ver) override {
-    if (!this->isAllowedToUseVersion(static_cast<VersionNumber>(Ver))) {
-      std::stringstream SS;
-      SS << "SPIR-V version was restricted to at most "
-         << to_string(getMaximumAllowedSPIRVVersion())
-         << " but a construct from the input requires SPIR-V version "
-         << to_string(Ver) << " or above\n";
-      getErrorLog().checkError(false, SPIRVEC_RequiresVersion, SS.str());
-      setInvalid();
-      return;
-    }
+    assert(this->isAllowedToUseVersion(static_cast<VersionNumber>(Ver)));
     SPIRVVersion = Ver;
   }
 
@@ -243,13 +186,6 @@ public:
                SPIRVWord Column) override;
   const std::shared_ptr<const SPIRVLine> &getCurrentLine() const override;
   void setCurrentLine(const std::shared_ptr<const SPIRVLine> &Line) override;
-  void addDebugLine(SPIRVEntry *E, SPIRVType *TheType, SPIRVId FileNameId,
-                    SPIRVWord LineStart, SPIRVWord LineEnd,
-                    SPIRVWord ColumnStart, SPIRVWord ColumnEnd) override;
-  const std::shared_ptr<const SPIRVExtInst> &
-  getCurrentDebugLine() const override;
-  void setCurrentDebugLine(
-      const std::shared_ptr<const SPIRVExtInst> &DebugLine) override;
   void addCapability(SPIRVCapabilityKind) override;
   void addCapabilityInternal(SPIRVCapabilityKind) override;
   void addExtension(ExtensionID) override;
@@ -279,8 +215,7 @@ public:
   template <class T> T *addType(T *Ty);
   SPIRVTypeArray *addArrayType(SPIRVType *, SPIRVConstant *) override;
   SPIRVTypeBool *addBoolType() override;
-  SPIRVTypeFloat *addFloatType(unsigned BitWidth,
-                               unsigned FloatingPointEncoding) override;
+  SPIRVTypeFloat *addFloatType(unsigned BitWidth) override;
   SPIRVTypeFunction *addFunctionType(SPIRVType *,
                                      const std::vector<SPIRVType *> &) override;
   SPIRVTypeInt *addIntegerType(unsigned BitWidth) override;
@@ -299,11 +234,6 @@ public:
   SPIRVTypeVector *addVectorType(SPIRVType *, SPIRVWord) override;
   SPIRVTypeJointMatrixINTEL *
   addJointMatrixINTELType(SPIRVType *, std::vector<SPIRVValue *>) override;
-  SPIRVTypeCooperativeMatrixKHR *
-  addCooperativeMatrixKHRType(SPIRVType *, std::vector<SPIRVValue *>) override;
-  SPIRVInstruction *
-  addCooperativeMatrixLengthKHRInst(SPIRVType *, SPIRVType *,
-                                    SPIRVBasicBlock *) override;
   SPIRVType *addOpaqueGenericType(Op) override;
   SPIRVTypeDeviceEvent *addDeviceEventType() override;
   SPIRVTypeQueue *addQueueType() override;
@@ -363,12 +293,8 @@ public:
                                const std::vector<SPIRVValue *> &,
                                SPIRVBasicBlock *,
                                SPIRVInstruction * = nullptr) override;
-  SPIRVEntry *createDebugInfo(SPIRVWord, SPIRVType *TheType,
-                              const std::vector<SPIRVWord> &) override;
   SPIRVEntry *addDebugInfo(SPIRVWord, SPIRVType *TheType,
                            const std::vector<SPIRVWord> &) override;
-  SPIRVEntry *addAuxData(SPIRVWord, SPIRVType *TheType,
-                         const std::vector<SPIRVWord> &) override;
   SPIRVEntry *addModuleProcessed(const std::string &) override;
   std::vector<SPIRVModuleProcessed *> getModuleProcessedVec() override;
   SPIRVInstruction *addBinaryInst(Op, SPIRVType *, SPIRVValue *, SPIRVValue *,
@@ -580,7 +506,6 @@ private:
   SPIRVStringVec StringVec;
   SPIRVMemberNameVec MemberNameVec;
   std::shared_ptr<const SPIRVLine> CurrentLine;
-  std::shared_ptr<const SPIRVExtInst> CurrentDebugLine;
   SPIRVDecorateVec DecorateVec;
   SPIRVDecGroupVec DecGroupVec;
   SPIRVGroupDecVec GroupDecVec;
@@ -592,11 +517,8 @@ private:
   SPIRVCapMap CapMap;
   SPIRVUnknownStructFieldMap UnknownStructFieldMap;
   std::map<unsigned, SPIRVTypeInt *> IntTypeMap;
-  SmallDenseMap<std::pair<unsigned, unsigned>, SPIRVTypeFloat *, 4>
-      FloatTypeMap;
   std::map<unsigned, SPIRVConstant *> LiteralMap;
   std::vector<SPIRVExtInst *> DebugInstVec;
-  std::vector<SPIRVExtInst *> AuxDataInstVec;
   std::vector<SPIRVModuleProcessed *> ModuleProcessedVec;
   SPIRVAliasInstMDVec AliasInstMDVec;
   SPIRVAliasInstMDMap AliasInstMDMap;
@@ -636,60 +558,6 @@ void SPIRVModuleImpl::addLine(SPIRVEntry *E, SPIRVId FileNameId, SPIRVWord Line,
   E->setLine(CurrentLine);
 }
 
-const std::shared_ptr<const SPIRVExtInst> &
-SPIRVModuleImpl::getCurrentDebugLine() const {
-  return CurrentDebugLine;
-}
-
-void SPIRVModuleImpl::setCurrentDebugLine(
-    const std::shared_ptr<const SPIRVExtInst> &DebugLine) {
-  CurrentDebugLine = DebugLine;
-}
-
-namespace {
-bool isDebugLineEqual(const SPIRVExtInst &CurrentDebugLine, SPIRVId FileNameId,
-                      SPIRVId LineStartId, SPIRVId LineEndId,
-                      SPIRVId ColumnStartId, SPIRVId ColumnEndId) {
-  assert(CurrentDebugLine.getExtOp() == SPIRVDebug::DebugLine);
-  const std::vector<SPIRVWord> CurrentDebugLineArgs =
-      CurrentDebugLine.getArguments();
-
-  using namespace SPIRVDebug::Operand::DebugLine;
-  return CurrentDebugLineArgs[SourceIdx] == FileNameId &&
-         CurrentDebugLineArgs[StartIdx] == LineStartId &&
-         CurrentDebugLineArgs[EndIdx] == LineEndId &&
-         CurrentDebugLineArgs[ColumnStartIdx] == ColumnStartId &&
-         CurrentDebugLineArgs[ColumnEndIdx] == ColumnEndId;
-}
-} // namespace
-
-void SPIRVModuleImpl::addDebugLine(SPIRVEntry *E, SPIRVType *TheType,
-                                   SPIRVId FileNameId, SPIRVWord LineStart,
-                                   SPIRVWord LineEnd, SPIRVWord ColumnStart,
-                                   SPIRVWord ColumnEnd) {
-  if (!(CurrentDebugLine &&
-        isDebugLineEqual(*CurrentDebugLine, FileNameId,
-                         getLiteralAsConstant(LineStart)->getId(),
-                         getLiteralAsConstant(LineEnd)->getId(),
-                         getLiteralAsConstant(ColumnStart)->getId(),
-                         getLiteralAsConstant(ColumnEnd)->getId()))) {
-    using namespace SPIRVDebug::Operand::DebugLine;
-
-    std::vector<SPIRVWord> DebugLineOps(OperandCount);
-    DebugLineOps[SourceIdx] = FileNameId;
-    DebugLineOps[StartIdx] = getLiteralAsConstant(LineStart)->getId();
-    DebugLineOps[EndIdx] = getLiteralAsConstant(LineEnd)->getId();
-    DebugLineOps[ColumnStartIdx] = getLiteralAsConstant(ColumnStart)->getId();
-    DebugLineOps[ColumnEndIdx] = getLiteralAsConstant(ColumnEnd)->getId();
-
-    CurrentDebugLine.reset(static_cast<SPIRVExtInst *>(
-        createDebugInfo(SPIRVDebug::DebugLine, TheType, DebugLineOps)));
-  }
-
-  assert(E && "invalid entry");
-  E->setDebugLine(CurrentDebugLine);
-}
-
 SPIRVValue *SPIRVModuleImpl::addSamplerConstant(SPIRVType *TheType,
                                                 SPIRVWord AddrMode,
                                                 SPIRVWord ParametricMode,
@@ -715,17 +583,6 @@ void SPIRVModuleImpl::addExtension(ExtensionID Ext) {
     return;
   }
   SPIRVExt.insert(ExtName);
-
-  // SPV_EXT_shader_atomic_float16_add extends the
-  // SPV_EXT_shader_atomic_float_add extension.
-  // The specification requires both extensions to be added to use
-  // AtomicFloat16AddEXT capability whereas getRequiredExtension()
-  // is able to return a single extensionID.
-  if (Ext == ExtensionID::SPV_EXT_shader_atomic_float16_add) {
-    SPIRVMap<ExtensionID, std::string>::find(
-        ExtensionID::SPV_EXT_shader_atomic_float_add, &ExtName);
-    SPIRVExt.insert(ExtName);
-  }
 }
 
 void SPIRVModuleImpl::addCapability(SPIRVCapabilityKind Cap) {
@@ -785,17 +642,13 @@ void SPIRVModuleImpl::layoutEntry(SPIRVEntry *E) {
   case OpExtInst: {
     SPIRVExtInst *EI = static_cast<SPIRVExtInst *>(E);
     if ((EI->getExtSetKind() == SPIRVEIS_Debug ||
-         EI->getExtSetKind() == SPIRVEIS_OpenCL_DebugInfo_100 ||
-         EI->getExtSetKind() == SPIRVEIS_NonSemantic_Shader_DebugInfo_100 ||
-         EI->getExtSetKind() == SPIRVEIS_NonSemantic_Shader_DebugInfo_200) &&
+         EI->getExtSetKind() == SPIRVEIS_OpenCL_DebugInfo_100) &&
         EI->getExtOp() != SPIRVDebug::Declare &&
         EI->getExtOp() != SPIRVDebug::Value &&
         EI->getExtOp() != SPIRVDebug::Scope &&
         EI->getExtOp() != SPIRVDebug::NoScope) {
       DebugInstVec.push_back(EI);
     }
-    if (EI->getExtSetKind() == SPIRVEIS_NonSemantic_AuxData)
-      AuxDataInstVec.push_back(EI);
     break;
   }
   case OpAsmTargetINTEL: {
@@ -1007,15 +860,9 @@ SPIRVTypeInt *SPIRVModuleImpl::addIntegerType(unsigned BitWidth) {
   return addType(Ty);
 }
 
-SPIRVTypeFloat *SPIRVModuleImpl::addFloatType(unsigned BitWidth,
-                                              unsigned FloatingPointEncoding) {
-  auto Desc = std::make_pair(BitWidth, FloatingPointEncoding);
-  auto Loc = FloatTypeMap.find(Desc);
-  if (Loc != FloatTypeMap.end())
-    return Loc->second;
-  auto *Ty = new SPIRVTypeFloat(this, getId(), BitWidth, FloatingPointEncoding);
-  FloatTypeMap[Desc] = Ty;
-  return addType(Ty);
+SPIRVTypeFloat *SPIRVModuleImpl::addFloatType(unsigned BitWidth) {
+  SPIRVTypeFloat *T = addType(new SPIRVTypeFloat(this, getId(), BitWidth));
+  return T;
 }
 
 SPIRVTypePointer *
@@ -1061,21 +908,6 @@ SPIRVModuleImpl::addJointMatrixINTELType(SPIRVType *CompType,
   return addType(new SPIRVTypeJointMatrixINTEL(this, getId(), CompType, Args));
 }
 
-SPIRVTypeCooperativeMatrixKHR *
-SPIRVModuleImpl::addCooperativeMatrixKHRType(SPIRVType *CompType,
-                                             std::vector<SPIRVValue *> Args) {
-  return addType(
-      new SPIRVTypeCooperativeMatrixKHR(this, getId(), CompType, Args));
-}
-
-SPIRVInstruction *SPIRVModuleImpl::addCooperativeMatrixLengthKHRInst(
-    SPIRVType *RetTy, SPIRVType *MatTy, SPIRVBasicBlock *BB) {
-  return addInstruction(
-      SPIRVInstTemplateBase::create(OpCooperativeMatrixLengthKHR, RetTy,
-                                    getId(), getVec(MatTy->getId()), BB, this),
-      BB);
-}
-
 SPIRVType *SPIRVModuleImpl::addOpaqueGenericType(Op TheOpCode) {
   return addType(new SPIRVTypeOpaqueGeneric(TheOpCode, this, getId()));
 }
@@ -1190,19 +1022,17 @@ SPIRVEntry *SPIRVModuleImpl::replaceForward(SPIRVForward *Forward,
                                             SPIRVEntry *Entry) {
   SPIRVId Id = Entry->getId();
   SPIRVId ForwardId = Forward->getId();
-  if (ForwardId == Id) {
+  if (ForwardId == Id)
     IdEntryMap[Id] = Entry;
-    // Annotations include name, decorations, execution modes
-    Entry->takeAnnotations(Forward);
-  } else {
+  else {
     auto Loc = IdEntryMap.find(Id);
     assert(Loc != IdEntryMap.end());
     IdEntryMap.erase(Loc);
     Entry->setId(ForwardId);
     IdEntryMap[ForwardId] = Entry;
-    // Replace current Id with ForwardId in decorates.
-    Entry->replaceTargetIdInDecorates(ForwardId);
   }
+  // Annotations include name, decorations, execution modes
+  Entry->takeAnnotations(Forward);
   delete Forward;
   return Entry;
 }
@@ -1466,23 +1296,11 @@ SPIRVInstruction *SPIRVModuleImpl::addExtInst(
       InsertBefore);
 }
 
-SPIRVEntry *
-SPIRVModuleImpl::createDebugInfo(SPIRVWord InstId, SPIRVType *TheType,
-                                 const std::vector<SPIRVWord> &Args) {
-  return new SPIRVExtInst(this, getId(), TheType, SPIRVEIS_OpenCL_DebugInfo_100,
-                          ExtInstSetIds[getDebugInfoEIS()], InstId, Args);
-}
-
 SPIRVEntry *SPIRVModuleImpl::addDebugInfo(SPIRVWord InstId, SPIRVType *TheType,
                                           const std::vector<SPIRVWord> &Args) {
-  return addEntry(createDebugInfo(InstId, TheType, Args));
-}
-
-SPIRVEntry *SPIRVModuleImpl::addAuxData(SPIRVWord InstId, SPIRVType *TheType,
-                                        const std::vector<SPIRVWord> &Args) {
-  return addEntry(new SPIRVExtInst(
-      this, getId(), TheType, SPIRVEIS_NonSemantic_AuxData,
-      getExtInstSetId(SPIRVEIS_NonSemantic_AuxData), InstId, Args));
+  return addEntry(
+      new SPIRVExtInst(this, getId(), TheType, SPIRVEIS_OpenCL_DebugInfo_100,
+                       ExtInstSetIds[getDebugInfoEIS()], InstId, Args));
 }
 
 SPIRVEntry *SPIRVModuleImpl::addModuleProcessed(const std::string &Process) {
@@ -1812,9 +1630,8 @@ SPIRVInstruction *SPIRVModuleImpl::addExpectKHRInst(SPIRVType *ResultTy,
 // Create AliasDomainDeclINTEL/AliasScopeDeclINTEL/AliasScopeListDeclINTEL
 // instructions
 template <typename AliasingInstType>
-SPIRVEntry *
-SPIRVModuleImpl::getOrAddMemAliasingINTELInst(std::vector<SPIRVId> Args,
-                                              llvm::MDNode *MD) {
+SPIRVEntry *SPIRVModuleImpl::getOrAddMemAliasingINTELInst(
+    std::vector<SPIRVId> Args, llvm::MDNode *MD) {
   assert(MD && "noalias/alias.scope metadata can't be null");
   // Don't duplicate aliasing instruction. For that use a map with a MDNode key
   if (AliasInstMDMap.find(MD) != AliasInstMDMap.end())
@@ -1825,23 +1642,20 @@ SPIRVModuleImpl::getOrAddMemAliasingINTELInst(std::vector<SPIRVId> Args,
 }
 
 // Create AliasDomainDeclINTEL instruction
-SPIRVEntry *
-SPIRVModuleImpl::getOrAddAliasDomainDeclINTELInst(std::vector<SPIRVId> Args,
-                                                  llvm::MDNode *MD) {
+SPIRVEntry *SPIRVModuleImpl::getOrAddAliasDomainDeclINTELInst(
+    std::vector<SPIRVId> Args, llvm::MDNode *MD) {
   return getOrAddMemAliasingINTELInst<SPIRVAliasDomainDeclINTEL>(Args, MD);
 }
 
 // Create AliasScopeDeclINTEL instruction
-SPIRVEntry *
-SPIRVModuleImpl::getOrAddAliasScopeDeclINTELInst(std::vector<SPIRVId> Args,
-                                                 llvm::MDNode *MD) {
+SPIRVEntry *SPIRVModuleImpl::getOrAddAliasScopeDeclINTELInst(
+    std::vector<SPIRVId> Args, llvm::MDNode *MD) {
   return getOrAddMemAliasingINTELInst<SPIRVAliasScopeDeclINTEL>(Args, MD);
 }
 
 // Create AliasScopeListDeclINTEL instruction
-SPIRVEntry *
-SPIRVModuleImpl::getOrAddAliasScopeListDeclINTELInst(std::vector<SPIRVId> Args,
-                                                     llvm::MDNode *MD) {
+SPIRVEntry *SPIRVModuleImpl::getOrAddAliasScopeListDeclINTELInst(
+    std::vector<SPIRVId> Args, llvm::MDNode *MD) {
   return getOrAddMemAliasingINTELInst<SPIRVAliasScopeListDeclINTEL>(Args, MD);
 }
 
@@ -2005,7 +1819,6 @@ spv_ostream &operator<<(spv_ostream &O, SPIRVModule &M) {
   SPIRVModuleImpl &MI = *static_cast<SPIRVModuleImpl *>(&M);
   // Start tracking of the current line with no line
   MI.CurrentLine.reset();
-  MI.CurrentDebugLine.reset();
 
   SPIRVEncoder Encoder(O);
   Encoder << MagicNumber << MI.SPIRVVersion
@@ -2054,7 +1867,7 @@ spv_ostream &operator<<(spv_ostream &O, SPIRVModule &M) {
   }
 
   if (M.isAllowedToUseExtension(
-          ExtensionID::SPV_INTEL_memory_access_aliasing)) {
+        ExtensionID::SPV_INTEL_memory_access_aliasing)) {
     O << SPIRVNL() << MI.AliasInstMDVec;
   }
 
@@ -2068,19 +1881,7 @@ spv_ostream &operator<<(spv_ostream &O, SPIRVModule &M) {
     O << SPIRVNL() << MI.AsmTargetVec << MI.AsmVec;
   }
 
-  // At this point we know that FunctionDefinition could have been included both
-  // into DebugInstVec and into basick block of function from FuncVec.
-  // By spec we should only have this instruction to be present inside the
-  // function body, so removing it from the DebugInstVec to avoid duplication.
-  MI.DebugInstVec.erase(
-      std::remove_if(MI.DebugInstVec.begin(), MI.DebugInstVec.end(),
-                     [](SPIRVExtInst *I) {
-                       return I->getExtOp() == SPIRVDebug::FunctionDefinition;
-                     }),
-      MI.DebugInstVec.end());
-
-  O << SPIRVNL() << MI.DebugInstVec << MI.AuxDataInstVec << SPIRVNL()
-    << MI.FuncVec;
+  O << SPIRVNL() << MI.DebugInstVec << SPIRVNL() << MI.FuncVec;
   return O;
 }
 
@@ -2149,6 +1950,36 @@ void SPIRVModuleImpl::addUnknownStructField(SPIRVTypeStruct *Struct, unsigned I,
   UnknownStructFieldMap[Struct].push_back(std::make_pair(I, ID));
 }
 
+static std::string to_string(uint32_t Version) {
+  std::string Res;
+  switch (Version) {
+  case static_cast<uint32_t>(VersionNumber::SPIRV_1_0):
+    Res = "1.0";
+    break;
+  case static_cast<uint32_t>(VersionNumber::SPIRV_1_1):
+    Res = "1.1";
+    break;
+  case static_cast<uint32_t>(VersionNumber::SPIRV_1_2):
+    Res = "1.2";
+    break;
+  case static_cast<uint32_t>(VersionNumber::SPIRV_1_3):
+    Res = "1.3";
+    break;
+  case static_cast<uint32_t>(VersionNumber::SPIRV_1_4):
+    Res = "1.4";
+    break;
+  default:
+    Res = "unknown";
+  }
+
+  Res += " (" + std::to_string(Version) + ")";
+  return Res;
+}
+
+static std::string to_string(VersionNumber Version) {
+  return to_string(static_cast<uint32_t>(Version));
+}
+
 std::istream &operator>>(std::istream &I, SPIRVModule &M) {
   SPIRVDecoder Decoder(I, M);
   SPIRVModuleImpl &MI = *static_cast<SPIRVModuleImpl *>(&M);
@@ -2165,7 +1996,9 @@ std::istream &operator>>(std::istream &I, SPIRVModule &M) {
   }
 
   Decoder >> MI.SPIRVVersion;
-  bool SPIRVVersionIsKnown = isSPIRVVersionKnown(MI.SPIRVVersion);
+  bool SPIRVVersionIsKnown =
+      static_cast<uint32_t>(VersionNumber::MinimumVersion) <= MI.SPIRVVersion &&
+      MI.SPIRVVersion <= static_cast<uint32_t>(VersionNumber::MaximumVersion);
   if (!M.getErrorLog().checkError(
           SPIRVVersionIsKnown, SPIRVEC_InvalidModule,
           "unsupported SPIR-V version number '" + to_string(MI.SPIRVVersion) +
