@@ -295,7 +295,6 @@ _SPIRV_OP(TypePipeStorage, 322)
 _SPIRV_OP(ConstantPipeStorage, 323)
 _SPIRV_OP(CreatePipeFromPipeStorage, 324)
 _SPIRV_OP(ModuleProcessed, 330)
-_SPIRV_OP(ExecutionModeId, 331)
 _SPIRV_OP(DecorateId, 332)
 _SPIRV_OP(GroupNonUniformElect, 333)
 _SPIRV_OP(GroupNonUniformAll, 334)
@@ -329,9 +328,6 @@ _SPIRV_OP(GroupNonUniformBitwiseXor, 361)
 _SPIRV_OP(GroupNonUniformLogicalAnd, 362)
 _SPIRV_OP(GroupNonUniformLogicalOr, 363)
 _SPIRV_OP(GroupNonUniformLogicalXor, 364)
-_SPIRV_OP(PtrEqual, 401)
-_SPIRV_OP(PtrNotEqual, 402)
-_SPIRV_OP(PtrDiff, 403)
 _SPIRV_OP(GroupNonUniformRotateKHR, 4431)
 _SPIRV_OP(SDotKHR, 4450)
 _SPIRV_OP(UDotKHR, 4451)
@@ -339,12 +335,6 @@ _SPIRV_OP(SUDotKHR, 4452)
 _SPIRV_OP(SDotAccSatKHR, 4453)
 _SPIRV_OP(UDotAccSatKHR, 4454)
 _SPIRV_OP(SUDotAccSatKHR, 4455)
-_SPIRV_OP(ReadClockKHR, 5056)
-_SPIRV_OP(TypeCooperativeMatrixKHR, 4456)
-_SPIRV_OP(CooperativeMatrixLoadKHR, 4457)
-_SPIRV_OP(CooperativeMatrixStoreKHR, 4458)
-_SPIRV_OP(CooperativeMatrixMulAddKHR, 4459)
-_SPIRV_OP(CooperativeMatrixLengthKHR, 4460)
 _SPIRV_OP(SubgroupShuffleINTEL, 5571)
 _SPIRV_OP(SubgroupShuffleDownINTEL, 5572)
 _SPIRV_OP(SubgroupShuffleUpINTEL, 5573)
