@@ -115,9 +115,6 @@ SPIRVType *SPIRVType::getVectorComponentType() const {
     return static_cast<const SPIRVTypeVector *>(this)->getComponentType();
   if (OpCode == internal::OpTypeJointMatrixINTEL)
     return static_cast<const SPIRVTypeJointMatrixINTEL *>(this)->getCompType();
-  if (OpCode == OpTypeCooperativeMatrixKHR)
-    return static_cast<const SPIRVTypeCooperativeMatrixKHR *>(this)
-        ->getCompType();
   assert(0 && "getVectorComponentType(): Not a vector or joint matrix type");
   return nullptr;
 }
@@ -159,18 +156,11 @@ bool SPIRVType::isTypeBool() const { return OpCode == OpTypeBool; }
 
 bool SPIRVType::isTypeComposite() const {
   return isTypeVector() || isTypeArray() || isTypeStruct() ||
-         isTypeJointMatrixINTEL() || isTypeCooperativeMatrixKHR();
+         isTypeJointMatrixINTEL();
 }
 
-bool SPIRVType::isTypeFloat(unsigned Bits,
-                            unsigned FloatingPointEncoding) const {
-  if (!isType<SPIRVTypeFloat>(this))
-    return false;
-  if (Bits == 0)
-    return true;
-  const auto *ThisFloat = static_cast<const SPIRVTypeFloat *>(this);
-  return ThisFloat->getBitWidth() == Bits &&
-         ThisFloat->getFloatingPointEncoding() == FloatingPointEncoding;
+bool SPIRVType::isTypeFloat(unsigned Bits) const {
+  return isType<SPIRVTypeFloat>(this, Bits);
 }
 
 bool SPIRVType::isTypeOCLImage() const {
@@ -204,10 +194,6 @@ bool SPIRVType::isTypeSampler() const { return OpCode == OpTypeSampler; }
 
 bool SPIRVType::isTypeImage() const { return OpCode == OpTypeImage; }
 
-bool SPIRVType::isTypeSampledImage() const {
-  return OpCode == OpTypeSampledImage;
-}
-
 bool SPIRVType::isTypeStruct() const { return OpCode == OpTypeStruct; }
 
 bool SPIRVType::isTypeVector() const { return OpCode == OpTypeVector; }
@@ -216,10 +202,6 @@ bool SPIRVType::isTypeJointMatrixINTEL() const {
   return OpCode == internal::OpTypeJointMatrixINTEL;
 }
 
-bool SPIRVType::isTypeCooperativeMatrixKHR() const {
-  return OpCode == OpTypeCooperativeMatrixKHR;
-}
-
 bool SPIRVType::isTypeVectorBool() const {
   return isTypeVector() && getVectorComponentType()->isTypeBool();
 }
@@ -316,24 +298,4 @@ void SPIRVTypeJointMatrixINTEL::decode(std::istream &I) {
   Decoder >> Id >> CompType >> Args;
 }
 
-SPIRVTypeCooperativeMatrixKHR::SPIRVTypeCooperativeMatrixKHR(
-    SPIRVModule *M, SPIRVId TheId, SPIRVType *CompType,
-    std::vector<SPIRVValue *> Args)
-    : SPIRVType(M, FixedWC, OpTypeCooperativeMatrixKHR, TheId),
-      CompType(CompType), Args(std::move(Args)) {}
-
-SPIRVTypeCooperativeMatrixKHR::SPIRVTypeCooperativeMatrixKHR()
-    : SPIRVType(OpTypeCooperativeMatrixKHR), CompType(nullptr),
-      Args({nullptr, nullptr, nullptr, nullptr}) {}
-
-void SPIRVTypeCooperativeMatrixKHR::encode(spv_ostream &O) const {
-  auto Encoder = getEncoder(O);
-  Encoder << Id << CompType << Args;
-}
-
-void SPIRVTypeCooperativeMatrixKHR::decode(std::istream &I) {
-  auto Decoder = getDecoder(I);
-  Decoder >> Id >> CompType >> Args;
-}
-
 } // namespace SPIRV
